@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                               Copyright (c) 2011
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -178,8 +177,7 @@ typedef struct
    (bFePollingOff = DSL_FALSE).
    The value ranges from  1 to 20 with 1 steps.
    The default configuration value is 10 which leads to 10s cycle in case of
-   nBasicUpdateCycle=1s.
-   Configuration parameter not used for the Vinax device*/
+   nBasicUpdateCycle=1s. */
    DSL_IN_OUT DSL_uint8_t nFeUpdateCycleFactorL2;
 } DSL_PM_ConfigData_t;
 
@@ -348,6 +346,9 @@ typedef struct
    An LOF failure is cleared when LOS failure is declared, or after 10 + 0.5 s
    of no SEF defect. */
    DSL_OUT DSL_uint32_t nLOFS;
+   /**
+   Forward Error Correction Seconds */
+   DSL_OUT DSL_uint32_t nFECS;
 } DSL_PM_LineSecData_t;
 
 /**
@@ -838,7 +839,7 @@ typedef struct
    \endif
 
    \note This structure is used within ADSL MIB interface only.
-         Thus it is only used for Danube Family.
+         Thus it is only used for ADSL only capable platforms.
 */
 typedef struct
 {
@@ -1239,8 +1240,6 @@ typedef struct
 
    \attention Please note the following conditions and/or requirements has to
       be taken into account for usage of retransmission functionality.
-      - ReTx support is ONLY available for Danube and ARX100 firmware (not for
-        Amazon-SE)
       - minimum version of ADSL PHY firmware to be used is R5
 */
 typedef struct
@@ -1255,6 +1254,13 @@ typedef struct
    The management entity shall read EFTR_min (at least) every 15 min to
    determine the minimum EFTR over the 15 min and 24 hour intervals. */
    DSL_OUT DSL_uint32_t nEftrMin;
+   /**
+   Counter for the number of bits which has been passed from the RTX receiver to
+   the next sub-layer. */
+   DSL_OUT DSL_uint32_t nErrorFreeBits;
+   /**
+   Counter for "leftr" defects seconds */
+   DSL_OUT DSL_uint32_t nLeftr;
 } DSL_PM_ReTxData_t;
 
 /**
@@ -1371,6 +1377,12 @@ typedef enum
    /**
    nEftrMin counter threshold crossing. */
    DSL_PM_RETXTHRESHCROSS_EFTR_MIN = 0x00000010,
+   /**
+   nErrorFreeBits counter threshold crossing. */
+   DSL_PM_RETXTHRESHCROSS_ERROR_FREE_BITS = 0x00000020,
+   /**
+   nLeftr counter threshold crossing. */
+   DSL_PM_RETXTHRESHCROSS_LEFTR = 0x00000040,
 } DSL_PM_BF_ReTxThresholdCrossing_t;
 
 /**
