@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                               Copyright (c) 2011
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -23,7 +22,6 @@
 
 #include "drv_dsl_cpe_vrx_msg_const.h"
 #include "drv_dsl_cpe_vrx_msg_config_pmd.h"
-#include "drv_dsl_cpe_vrx_msg_debug.h"
 #include "drv_dsl_cpe_vrx_msg_dmt_scope.h"
 #include "drv_dsl_cpe_vrx_msg_ghs_status.h"
 #include "drv_dsl_cpe_vrx_msg_olr.h"
@@ -75,7 +73,7 @@ DSL_Error_t DSL_DRV_VRX_ChRequestMessage(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgModemFsmStateGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgModemFsmStateGet(
    DSL_Context_t *pContext,
    DSL_uint8_t *pAck);
 
@@ -283,7 +281,7 @@ DSL_Error_t DSL_DRV_VRX_SnrAllocationTableNeGet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_BitAllocationTableGet(
+DSL_Error_t DSL_DRV_VRX_BitAllocationTableGet(
    DSL_Context_t *pContext,
    const DSL_AccessDir_t nDirection,
    DSL_G997_NSCData8_t *pData,
@@ -336,7 +334,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgOhOptionsSet(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgSelectedProfileVdsl2Get(
+DSL_Error_t DSL_DRV_VRX_SendMsgSelectedProfileVdsl2Get(
    DSL_Context_t *pContext);
 
 /*
@@ -350,7 +348,7 @@ DSL_Error_t DSL_DRV_VXX_SendMsgSelectedProfileVdsl2Get(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgModemFSMFailReasonGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgModemFSMFailReasonGet(
    DSL_Context_t *pContext,
    DSL_uint8_t *pAck);
 
@@ -364,7 +362,7 @@ DSL_Error_t DSL_DRV_VXX_SendMsgModemFSMFailReasonGet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgXtseStatusGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgXtseStatusGet(
    DSL_Context_t *pContext);
 
 /*
@@ -429,6 +427,21 @@ DSL_Error_t DSL_DRV_VRX_SendMsgLineStatusPerBandGet(
    DSL_AccessDir_t nDirection,
    DSL_uint8_t *pAck);
 
+/*
+   This function sends the firmware message "CMD_PBO_AELEM_Status_Get".
+
+   \param pContext Pointer to dsl library context structure, [I]
+   \param pAck pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS (0) in case of success
+   - DSL_ERROR (-1) if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgUsPowerBackOffStatusGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
 #ifdef INCLUDE_DSL_G997_LINE_INVENTORY
 /*
    Read all the Inventory information of the Far End from the device,
@@ -441,7 +454,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgLineStatusPerBandGet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgInventoryFeGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgInventoryFeGet(
    DSL_Context_t *pContext);
 #endif /* INCLUDE_DSL_G997_LINE_INVENTORY*/
 
@@ -449,7 +462,6 @@ DSL_Error_t DSL_DRV_VXX_SendMsgInventoryFeGet(
    Write all the Inventory information of the Near End to the device
 
    \param pContext   Pointer to dsl cpe library context structure, [I]
-   \param pData      Pointer to the Inventory data to set, [I]
 
    \return
    Return values are defined within the DSL_Error_t definition
@@ -463,11 +475,6 @@ DSL_Error_t DSL_DRV_VRX_SendMsgInventoryNeSet(
    This function sends the firmware message "CMD_OLR_Control".
 
    \param pContext Pointer to dsl library context structure, [I]
-   \param bAutoSRA_DS AutoSRA control DS, [I]
-   \param bAutoSRA_US AutoSRA control US, [I]
-   \param bSos_DS SOS control DS, [I]
-   \param bSos_US SOS control US, [I]
-
 
    \return
    Return values are defined within the DSL_Error_t definition
@@ -475,26 +482,20 @@ DSL_Error_t DSL_DRV_VRX_SendMsgInventoryNeSet(
    - DSL_ERROR (-1) if operation failed
 */
 DSL_Error_t DSL_DRV_VRX_SendMsgOlrControl(
-   DSL_Context_t *pContext,
-   DSL_boolean_t bAutoSRA_DS,
-   DSL_boolean_t bAutoSRA_US,
-   DSL_boolean_t bSos_DS,
-   DSL_boolean_t bSos_US);
+   DSL_Context_t *pContext);
 
 /*
-   This function sends the firmware message "CMD_RTX_DS_Configure".
+   This function sends the firmware message "CMD_RTX_Control".
 
    \param pContext Pointer to dsl library context structure, [I]
-   \param bReTxEnable ReTx control DS
 
    \return
    Return values are defined within the DSL_Error_t definition
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VRX_SendMsgRtxDsConfigure(
-   DSL_Context_t *pContext,
-   DSL_boolean_t bReTxEnable);
+DSL_Error_t DSL_DRV_VRX_SendMsgRtxControl(
+   DSL_Context_t *pContext);
 
 /*
    This function sends the firmware message "CMD_BandConfig_US/DS_Get"
@@ -509,7 +510,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgRtxDsConfigure(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgBandControlGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgBandControlGet(
    DSL_Context_t *pContext,
    const DSL_AccessDir_t nDirection,
    DSL_BandList_t *pBandList);
@@ -567,7 +568,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgTestParamsAuxGet(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgSpar1Get(
+DSL_Error_t DSL_DRV_VRX_SendMsgSpar1Get(
    DSL_Context_t *pContext);
 
 #ifdef INCLUDE_DSL_G997_LINE_INVENTORY
@@ -682,7 +683,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgBearerChannelStatusGet(
 */
 DSL_Error_t DSL_DRV_VRX_SendMsgTxL3RequestFailReasonGet(
    DSL_Context_t *pContext,
-   DSL_VNX_L3RequestFailReason_t *pFailReason);
+   DSL_VRX_L3RequestFailReason_t *pFailReason);
 
 /*
    This function send the firmware message "CMD_TxL3RequestStatusGet".
@@ -697,10 +698,10 @@ DSL_Error_t DSL_DRV_VRX_SendMsgTxL3RequestFailReasonGet(
 */
 DSL_Error_t DSL_DRV_VRX_SendMsgTxL3RequestStatusGet(
    DSL_Context_t *pContext,
-   DSL_VNX_L3RequestStatus_t *pStatus);
+   DSL_VRX_L3RequestStatus_t *pStatus);
 
 /*
-   This function send the firmware message "CMD_L3ShutdownRequest".
+   This function send the firmware message "CMD_ShutdownRequest".
 
    \param pContext Pointer to DSL CPE library context structure, [I]
 
@@ -709,7 +710,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgTxL3RequestStatusGet(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VRX_SendMsgL3ShutdownRequest(
+DSL_Error_t DSL_DRV_VRX_SendMsgShutdownRequest(
    DSL_Context_t *pContext);
 
 /*
@@ -725,7 +726,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgL3ShutdownRequest(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgXtseConfigure(
+DSL_Error_t DSL_DRV_VRX_SendMsgXtseConfigure(
    DSL_Context_t *pContext,
    DSL_G997_XTUSystemEnablingData_t *pXTSE);
 
@@ -749,7 +750,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgLineStatusGet(
 
 /*
    This function sends the VRX firmware message
-   CMD_BearerChsDS_RTX_Get
+   CMD_RTX_BearerChsDS_Get
 
    \param pContext Pointer to dsl library context structure, [I]
    \param pAck Pointer to the msg ACK, [O]
@@ -759,13 +760,47 @@ DSL_Error_t DSL_DRV_VRX_SendMsgLineStatusGet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VRX_SendMsgBearerChsDsRtxGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgBearerChsRtxGet(
+   DSL_Context_t *pContext,
+   DSL_AccessDir_t nDirection,
+   DSL_uint8_t *pAck);
+
+/*
+   This function sends the VRX firmware message
+   CMD_RTX_DS_StatsGet or CMD_RTX_US_StatsGet
+
+   \param pContext Pointer to dsl library context structure, [I]
+   \param pAck Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgRtxStatsGet(
+   DSL_Context_t *pContext,
+   DSL_AccessDir_t nDirection,
+   DSL_uint8_t *pAck);
+
+/*
+   This function sends the VRX firmware message
+   CMD_RTX_StatusGet
+
+   \param pContext Pointer to dsl library context structure, [I]
+   \param pAck Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgRtxEnableStatusGet(
    DSL_Context_t *pContext,
    DSL_uint8_t *pAck);
 
 /*
    This function sends the VRX firmware message
-   CMD_RTX_DS_StatsGet
+   CMD_RTX_PM_DS_Get
 
    \param pContext Pointer to dsl library context structure, [I]
    \param pAck Pointer to the msg ACK, [O]
@@ -775,40 +810,9 @@ DSL_Error_t DSL_DRV_VRX_SendMsgBearerChsDsRtxGet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VRX_SendMsgRtxDsStatsGet(
-   DSL_Context_t *pContext,
-   DSL_uint8_t *pAck);
-
-/*
-   This function sends the VRX firmware message
-   CMD_VDSL_RTX_StatusGet
-
-   \param pContext Pointer to dsl library context structure, [I]
-   \param pAck Pointer to the msg ACK, [O]
-
-   \return
-   Return values are defined within the DSL_Error_t definition
-   - DSL_SUCCESS in case of success
-   - DSL_ERROR if operation failed
-*/
-DSL_Error_t DSL_DRV_VRX_SendMsgRtxDsEnableStatusGet(
-   DSL_Context_t *pContext,
-   DSL_uint8_t *pAck);
-
-/*
-   This function sends the VRX firmware message
-   CMD_RTX_PMwoThreshDS_Get
-
-   \param pContext Pointer to dsl library context structure, [I]
-   \param pAck Pointer to the msg ACK, [O]
-
-   \return
-   Return values are defined within the DSL_Error_t definition
-   - DSL_SUCCESS in case of success
-   - DSL_ERROR if operation failed
-*/
-DSL_Error_t DSL_DRV_VRX_SendMsgRtxPmwoThreshDsGet(
+DSL_Error_t DSL_DRV_VRX_SendMsgRtxPmGet(
    DSL_Context_t *pContext,
+   DSL_AccessDir_t nDirection,
    DSL_uint8_t *pAck);
 
 /*
@@ -858,7 +862,7 @@ DSL_Error_t DSL_DRV_VRX_SendMsgFrameDataExt2Get(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgTxControlSet(
+DSL_Error_t DSL_DRV_VRX_SendMsgTxControlSet(
    DSL_Context_t *pContext,
    const DSL_uint16_t TxControl);
 
@@ -921,11 +925,28 @@ DSL_Error_t DSL_DRV_VRX_SendOperationOptionsSet(
    - DSL_SUCCESS in case of success
    - DSL_ERROR if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgModemFsmOptionsSet(
+DSL_Error_t DSL_DRV_VRX_SendMsgModemFsmOptionsSet(
    DSL_Context_t *pContext,
    const DSL_boolean_t bAutoRestart,
    const DSL_boolean_t bDiagMode);
 
+/*
+   This function sends the VRX firmware message CMD_ModemFSM_Options2Set
+   to configure some chip hardware related issues.
+
+   \param pContext - Pointer to DSL CPE library context structure, [I]
+
+   \param bEnableVirtualNoise - Enable/Disable virtual noise flag
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgModemFsmOptions2Set(
+   DSL_Context_t *pContext,
+   DSL_boolean_t bEnableVirtualNoise);
+
 /*
    This function sends the firmware message "CMD_HS_ToneGroupSet".
    It configures the hand shake tone set according to the given config.
@@ -954,10 +975,57 @@ DSL_Error_t DSL_DRV_VRX_SendMsgHsToneGroupSet(
    - DSL_SUCCESS (0) in case of success
    - DSL_ERROR (-1) if operation failed
 */
-DSL_Error_t DSL_DRV_VXX_SendMsgModemStateSet(
+DSL_Error_t DSL_DRV_VRX_SendMsgModemStateSet(
    DSL_Context_t *pContext,
    const DSL_uint16_t nMode);
 
+#if defined(INCLUDE_DSL_CPE_API_VRX)
+/*
+   This function sends the VRX firmware message "CMD_ShutdownRequest".
+
+   \param pContext Pointer to dsl cpe library context structure, [I]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS (0) in case of success
+   - DSL_ERROR (-1) if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgOrderlyShutDownRequest(
+   DSL_Context_t *pContext);
+#endif /* INCLUDE_DSL_CPE_API_VRX */
+
+/**
+   This function sends the VRX firmware undefined message
+   to freeze TX link
+
+   \param pContext - Pointer to DSL library context structure,
+   \param nVal  - firmware internal value
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgLinkFreezeTX(
+   DSL_Context_t *pContext,
+   const DSL_uint16_t nVal);
+
+/**
+   This function sends the VRX firmware undefined message
+   to freeze RX link
+
+   \param pContext - Pointer to DSL library context structure,
+   \param nVal  - firmware internal value
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgLinkFreezeRX(
+   DSL_Context_t *pContext,
+   const DSL_uint16_t nVal);
+
 /**
    This function sends the VRX firmware message CMD_VersionInfoGet.
 
@@ -1024,6 +1092,9 @@ DSL_Error_t DSL_DRV_VRX_SendMsgHybridInfoGet(
 DSL_Error_t DSL_DRV_VRX_SendMsgMiscConfigSet(
    DSL_Context_t *pContext);
 
+DSL_Error_t DSL_DRV_VRX_SendMsgTestOptionsSet(
+   DSL_Context_t *pContext);
+
 /** @} DRV_DSL_DEVICE */
 
 #ifdef INCLUDE_DSL_SYSTEM_INTERFACE
