@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2012
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -49,6 +48,7 @@
 #define ACK_ModemFSM_StateGet_STEADY_STATE_TC_SYNC 8
 #define ACK_ModemFSM_StateGet_DIAGMODE_STATE 9
 #define ACK_ModemFSM_StateGet_T1413_STATE 14
+#define ACK_ModemFSM_StateGet_PRE_FAIL_STATE 15
 #define ACK_ModemFSM_StateGet_GHS_BONDING_CLR_STATE 16
 #define ACK_ModemFSM_StateGet_MFD_STATE 18
 #define ACK_ModemFSM_StateGet_MFD_COMPLETE_STATE 19
@@ -66,9 +66,13 @@
 #define EVT_ModemFSM_StateGet_STEADY_STATE_TC_SYNC 8
 #define EVT_ModemFSM_StateGet_DIAGMODE_STATE 9
 #define EVT_ModemFSM_StateGet_T1413_STATE 14
+#define EVT_ModemFSM_StateGet_PRE_FAIL_STATE 15
 #define EVT_ModemFSM_StateGet_GHS_BONDING_CLR_STATE 16
 #define EVT_ModemFSM_StateGet_MFD_STATE 18
 #define EVT_ModemFSM_StateGet_MFD_COMPLETE_STATE 19
+#define EVT_ModemFSM_StateGet_L0 0
+#define EVT_ModemFSM_StateGet_L2 2
+#define EVT_ModemFSM_StateGet_L3 3
 #define EVT_ModemReady_MRERR_OK 0x0
 #define EVT_ModemReady_MRWARN_OK 0x0
 #define CMD_ModemFSM_StateSet_LINKRES 0
@@ -89,11 +93,16 @@
 #define ALM_ModemFSM_FailReasonGet_S_LOF 0x11
 #define ALM_ModemFSM_FailReasonGet_S_LPR 0x12
 #define ALM_ModemFSM_FailReasonGet_S_LOM 0x13
+#define ALM_ModemFSM_FailReasonGet_S_FAST_LOS 0x14
 #define ALM_ModemFSM_FailReasonGet_S_ESE 0x15
+#define ALM_ModemFSM_FailReasonGet_S_SESX 0x16
+#define ALM_ModemFSM_FailReasonGet_S_ESX 0x17
 #define ALM_ModemFSM_FailReasonGet_S_OOS0 0x18
 #define ALM_ModemFSM_FailReasonGet_S_LCD0 0x20
 #define ALM_ModemFSM_FailReasonGet_S_NCD0 0x22
 #define ALM_ModemFSM_FailReasonGet_S_CRC_DS 0x24
+#define ALM_ModemFSM_FailReasonGet_S_PP_DRIVER 0x25
+#define ALM_ModemFSM_FailReasonGet_S_INTENDED_LOCAL_SHUTDOWN 0x26
 #define ALM_ModemFSM_FailReasonGet_E_OK 0x0
 #define ALM_ModemFSM_FailReasonGet_E_CONFIG 0x1
 #define ALM_ModemFSM_FailReasonGet_E_NOTFEASIBLE 0x2
@@ -119,11 +128,16 @@
 #define ACK_ModemFSM_FailReasonGet_S_LOF 0x11
 #define ACK_ModemFSM_FailReasonGet_S_LPR 0x12
 #define ACK_ModemFSM_FailReasonGet_S_LOM 0x13
+#define ACK_ModemFSM_FailReasonGet_S_FAST_LOS 0x14
 #define ACK_ModemFSM_FailReasonGet_S_ESE 0x15
+#define ACK_ModemFSM_FailReasonGet_S_SESX 0x16
+#define ACK_ModemFSM_FailReasonGet_S_ESX 0x17
 #define ACK_ModemFSM_FailReasonGet_S_OOS0 0x18
 #define ACK_ModemFSM_FailReasonGet_S_LCD0 0x20
 #define ACK_ModemFSM_FailReasonGet_S_NCD0 0x22
 #define ACK_ModemFSM_FailReasonGet_S_CRC_DS 0x24
+#define ACK_ModemFSM_FailReasonGet_S_PP_DRIVER 0x25
+#define ACK_ModemFSM_FailReasonGet_S_INTENDED_LOCAL_SHUTDOWN 0x26
 #define ACK_ModemFSM_FailReasonGet_E_OK 0x0
 #define ACK_ModemFSM_FailReasonGet_E_CONFIG 0x1
 #define ACK_ModemFSM_FailReasonGet_E_NOTFEASIBLE 0x2
@@ -162,6 +176,12 @@
 #define CMD_ErasureControlSet_MAX_INP 0x1
 #define CMD_Misc_ConfigSet_GHSMODE 0x0
 #define CMD_Misc_ConfigSet_T1413MODE 0x1
+#define CMD_OperatorSelect_TELCO_OFF 0
+#define CMD_OperatorSelect_TELCO_DTAG 1
+#define CMD_OperatorSelect_TELCO_BT 2
+#define CMD_OperatorSelect_TELCO_TS 3
+#define CMD_OperatorSelect_TELCO_FT 4
+#define CMD_OperatorSelect_TELCO_KPN 5
 /* ----- Message Specific Constants Definition section (End) ----- */
 
 /** Message ID for CMD_ModemFSM_StateGet */
@@ -357,24 +377,77 @@ typedef struct CMD_ReInitNE_Configure CMD_ReInitNE_Configure_t;
 */
 typedef struct ACK_ReInitNE_Configure ACK_ReInitNE_Configure_t;
 
-/** Message ID for CMD_L3ShutdownRequest */
-#define CMD_L3SHUTDOWNREQUEST 0x0341
+/** Message ID for CMD_ReinitThreshConfigure */
+#define CMD_REINITTHRESHCONFIGURE 0x1E62
 
 /**
-   Triggers the sending of an L3 orderly shutdown request to the remote side.If
-   applied at the CPE and accepted by the CO, the following shall happen: The
-   CPE-Host forces L3 entry with transition to RESET state by applying
-   CMD_ModemFSM_StateGet.
+   Configuration of reinitialization trigger definitions.
 */
-typedef struct CMD_L3ShutdownRequest CMD_L3ShutdownRequest_t;
+typedef struct CMD_ReinitThreshConfigure CMD_ReinitThreshConfigure_t;
 
-/** Message ID for ACK_L3ShutdownRequest */
-#define ACK_L3SHUTDOWNREQUEST 0x0341
+/** Message ID for ACK_ReinitThreshConfigure */
+#define ACK_REINITTHRESHCONFIGURE 0x1E62
 
 /**
-   Acknowledgement for CMD_L3ShutdownRequest.
+   Acknowledgement for the message ACK_ReinitThreshConfigure.
 */
-typedef struct ACK_L3ShutdownRequest ACK_L3ShutdownRequest_t;
+typedef struct ACK_ReinitThreshConfigure ACK_ReinitThreshConfigure_t;
+
+/** Message ID for CMD_ShutdownRequest */
+#define CMD_SHUTDOWNREQUEST 0x0341
+
+/**
+   Triggers a shutdown request, either as "L3 orderly shutdown" towards the
+   remote side or as "locally forced shutdown" to the DSL-FW without sending a
+   request to the remote side.After an "L3 orderly shutdown" request was
+   accepted by the CO, the following shall happen: The CPE-Host forces L3 entry
+   with transition to RESET state by applying CMD_ModemFSM_StateGet.A "locally
+   forced shutdown" always results in exiting Showtime.
+*/
+typedef struct CMD_ShutdownRequest CMD_ShutdownRequest_t;
+
+/** Message ID for ACK_ShutdownRequest */
+#define ACK_SHUTDOWNREQUEST 0x0341
+
+/**
+   Acknowledgement for CMD_ShutdownRequest.
+*/
+typedef struct ACK_ShutdownRequest ACK_ShutdownRequest_t;
+
+/** Message ID for CMD_PrefailConfigure */
+#define CMD_PREFAILCONFIGURE 0x384A
+
+/**
+   For a "locally forced shutdown" (see CMD_ShutdownRequest) the time is set
+   that the modem state machine will wait in PRE_FAIL state before entering FAIL
+   state.
+*/
+typedef struct CMD_PrefailConfigure CMD_PrefailConfigure_t;
+
+/** Message ID for ACK_PrefailConfigure */
+#define ACK_PREFAILCONFIGURE 0x384A
+
+/**
+   Acknowledgement for CMD_PrefailConfigure.
+*/
+typedef struct ACK_PrefailConfigure ACK_PrefailConfigure_t;
+
+/** Message ID for CMD_PrefailDataGet */
+#define CMD_PREFAILDATAGET 0x390A
+
+/**
+   Requests information about PRE_FAIL state data.
+*/
+typedef struct CMD_PrefailDataGet CMD_PrefailDataGet_t;
+
+/** Message ID for ACK_PrefailDataGet */
+#define ACK_PREFAILDATAGET 0x390A
+
+/**
+   Acknowledgement for CMD_PrefailDataGet. It provides information about
+   PRE_FAIL state data.
+*/
+typedef struct ACK_PrefailDataGet ACK_PrefailDataGet_t;
 
 /** Message ID for CMD_RxL3RequestStatusGet */
 #define CMD_RXL3REQUESTSTATUSGET 0x0402
@@ -556,6 +629,42 @@ typedef struct CMD_UPBO_KL0Get CMD_UPBO_KL0Get_t;
 */
 typedef struct ACK_UPBO_KL0Get ACK_UPBO_KL0Get_t;
 
+/** Message ID for CMD_PBO_AELEM_Status_Get */
+#define CMD_PBO_AELEM_STATUS_GET 0xEA03
+
+/**
+   Requests status parameters for the Upstream  Power  Back-Off  (UPBO)
+   alternative  electrical  length  estimation  method (AELEM).
+*/
+typedef struct CMD_PBO_AELEM_Status_Get CMD_PBO_AELEM_Status_Get_t;
+
+/** Message ID for ACK_PBO_AELEM_Status_Get */
+#define ACK_PBO_AELEM_STATUS_GET 0xEA03
+
+/**
+   Upstream  Power  Back-Off  (UPBO)  status  parameters  for  the  alternative
+   electrical  length  estimation  method (AELEM) are reported.
+*/
+typedef struct ACK_PBO_AELEM_Status_Get ACK_PBO_AELEM_Status_Get_t;
+
+/** Message ID for CMD_PSD_CeilingDS_Set */
+#define CMD_PSD_CEILINGDS_SET 0x3848
+
+/**
+   Enables for each VDSL2 Profile an adaptive PSD optimization (ceiling)
+   algorithm. Currently only required for Profile 8b due to the high transmit
+   power.
+*/
+typedef struct CMD_PSD_CeilingDS_Set CMD_PSD_CeilingDS_Set_t;
+
+/** Message ID for ACK_PSD_CeilingDS_Set */
+#define ACK_PSD_CEILINGDS_SET 0x3848
+
+/**
+   Acknowledgement for message CMD_PSD_CeilingDS_Set.
+*/
+typedef struct ACK_PSD_CeilingDS_Set ACK_PSD_CeilingDS_Set_t;
+
 /** Message ID for CMD_NoiseMarginDeltaSet */
 #define CMD_NOISEMARGINDELTASET 0x1C45
 
@@ -705,37 +814,38 @@ typedef struct CMD_OperationOptionsSet CMD_OperationOptionsSet_t;
 */
 typedef struct ACK_OperationOptionsSet ACK_OperationOptionsSet_t;
 
-/** Message ID for CMD_InteropConfigSet */
-#define CMD_INTEROPCONFIGSET 0x6743
+/** Message ID for CMD_OperatorSelect */
+#define CMD_OPERATORSELECT 0x1562
 
 /**
-   The message configures interoperability settings for ADSL.
+   The message selects a DSL operator. The information is used to configure
+   operator specific settings inside the DSL firmware.
 */
-typedef struct CMD_InteropConfigSet CMD_InteropConfigSet_t;
+typedef struct CMD_OperatorSelect CMD_OperatorSelect_t;
 
-/** Message ID for ACK_InteropConfigSet */
-#define ACK_INTEROPCONFIGSET 0x6743
+/** Message ID for ACK_OperatorSelect */
+#define ACK_OPERATORSELECT 0x1562
 
 /**
-   This is the acknowledgement for CMD_InteropConfigSet.
+   This is the acknowledgement for ACK_OperatorSelect.
 */
-typedef struct ACK_InteropConfigSet ACK_InteropConfigSet_t;
+typedef struct ACK_OperatorSelect ACK_OperatorSelect_t;
 
-/** Message ID for CMD_InteropConfigGet */
-#define CMD_INTEROPCONFIGGET 0x6703
+/** Message ID for CMD_TestOptionsSet */
+#define CMD_TESTOPTIONSSET 0x1C44
 
 /**
-   The message requests the interoperability settings.
+   The messages configures settings for test modes.
 */
-typedef struct CMD_InteropConfigGet CMD_InteropConfigGet_t;
+typedef struct CMD_TestOptionsSet CMD_TestOptionsSet_t;
 
-/** Message ID for ACK_InteropConfigGet */
-#define ACK_INTEROPCONFIGGET 0x6703
+/** Message ID for ACK_TestOptionsSet */
+#define ACK_TESTOPTIONSSET 0x1C44
 
 /**
-   This is the acknowledgement for CMD_InteropConfigGet.
+   This is the acknowledgement for CMD_TestOptionsSet.
 */
-typedef struct ACK_InteropConfigGet ACK_InteropConfigGet_t;
+typedef struct ACK_TestOptionsSet ACK_TestOptionsSet_t;
 
 /** Message ID for CMD_ClockSet */
 #define CMD_CLOCKSET 0x0F62
@@ -818,6 +928,10 @@ struct EVT_ModemFSM_StateGet
    DSL_uint16_t Length;
    /** Modem Status */
    DSL_uint16_t ModemState;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
+   /** Line Power Management State */
+   DSL_uint16_t LxState : 2;
 #else
    /** Index */
    DSL_uint16_t Index;
@@ -825,6 +939,10 @@ struct EVT_ModemFSM_StateGet
    DSL_uint16_t Length;
    /** Modem Status */
    DSL_uint16_t ModemState;
+   /** Line Power Management State */
+   DSL_uint16_t LxState : 2;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
 #endif
 } __PACKED__ ;
 
@@ -927,8 +1045,22 @@ struct ALM_ModemFSM_FailReasonGet
    DSL_uint8_t ErrorCode;
    /** Failure State Information */
    DSL_uint16_t FW_FailCode;
-   /** Reserved */
-   DSL_uint16_t Res0[8];
+   /** Tx Symbol Count, LSW */
+   DSL_uint16_t TxSymCountLSW;
+   /** Tx Symbol Count, MSW */
+   DSL_uint16_t TxSymCountMSW;
+   /** Tx State at Failure */
+   DSL_uint16_t TxStateOnFail;
+   /** Tx Sub State at Failure */
+   DSL_uint16_t TxSubStateOnFail;
+   /** Rx Symbol Count, LSW */
+   DSL_uint16_t RxSymCountLSW;
+   /** Rx Symbol Count, MSW */
+   DSL_uint16_t RxSymCountMSW;
+   /** Rx State at Failure */
+   DSL_uint16_t RxStateOnFail;
+   /** Rx Sub State at Failure */
+   DSL_uint16_t RxSubStateOnFail;
 #else
    /** Index */
    DSL_uint16_t Index;
@@ -940,8 +1072,22 @@ struct ALM_ModemFSM_FailReasonGet
    DSL_uint8_t SubErrorCode;
    /** Failure State Information */
    DSL_uint16_t FW_FailCode;
-   /** Reserved */
-   DSL_uint16_t Res0[8];
+   /** Tx Symbol Count, LSW */
+   DSL_uint16_t TxSymCountLSW;
+   /** Tx Symbol Count, MSW */
+   DSL_uint16_t TxSymCountMSW;
+   /** Tx State at Failure */
+   DSL_uint16_t TxStateOnFail;
+   /** Tx Sub State at Failure */
+   DSL_uint16_t TxSubStateOnFail;
+   /** Rx Symbol Count, LSW */
+   DSL_uint16_t RxSymCountLSW;
+   /** Rx Symbol Count, MSW */
+   DSL_uint16_t RxSymCountMSW;
+   /** Rx State at Failure */
+   DSL_uint16_t RxStateOnFail;
+   /** Rx Sub State at Failure */
+   DSL_uint16_t RxSubStateOnFail;
 #endif
 } __PACKED__ ;
 
@@ -981,8 +1127,22 @@ struct ACK_ModemFSM_FailReasonGet
    DSL_uint8_t ErrorCode;
    /** Failure State Information */
    DSL_uint16_t FW_FailCode;
-   /** Reserved */
-   DSL_uint16_t Res0[8];
+   /** Tx Symbol Count, LSW */
+   DSL_uint16_t TxSymCountLSW;
+   /** Tx Symbol Count, MSW */
+   DSL_uint16_t TxSymCountMSW;
+   /** Tx State at Failure */
+   DSL_uint16_t TxStateOnFail;
+   /** Tx Sub State at Failure */
+   DSL_uint16_t TxSubStateOnFail;
+   /** Rx Symbol Count, LSW */
+   DSL_uint16_t RxSymCountLSW;
+   /** Rx Symbol Count, MSW */
+   DSL_uint16_t RxSymCountMSW;
+   /** Rx State at Failure */
+   DSL_uint16_t RxStateOnFail;
+   /** Rx Sub State at Failure */
+   DSL_uint16_t RxSubStateOnFail;
 #else
    /** Index */
    DSL_uint16_t Index;
@@ -994,8 +1154,22 @@ struct ACK_ModemFSM_FailReasonGet
    DSL_uint8_t SubErrorCode;
    /** Failure State Information */
    DSL_uint16_t FW_FailCode;
-   /** Reserved */
-   DSL_uint16_t Res0[8];
+   /** Tx Symbol Count, LSW */
+   DSL_uint16_t TxSymCountLSW;
+   /** Tx Symbol Count, MSW */
+   DSL_uint16_t TxSymCountMSW;
+   /** Tx State at Failure */
+   DSL_uint16_t TxStateOnFail;
+   /** Tx Sub State at Failure */
+   DSL_uint16_t TxSubStateOnFail;
+   /** Rx Symbol Count, LSW */
+   DSL_uint16_t RxSymCountLSW;
+   /** Rx Symbol Count, MSW */
+   DSL_uint16_t RxSymCountMSW;
+   /** Rx State at Failure */
+   DSL_uint16_t RxStateOnFail;
+   /** Rx Sub State at Failure */
+   DSL_uint16_t RxSubStateOnFail;
 #endif
 } __PACKED__ ;
 
@@ -1011,34 +1185,42 @@ struct CMD_ModemFSM_OptionsSet
    /** Length */
    DSL_uint16_t Length;
    /** Reserved */
-   DSL_uint16_t Res0 : 7;
-   /** L2 Low-Power Mode (ADSL only) */
+   DSL_uint16_t Res0 : 5;
+   /** L2 Extensions of G.992.3 Amd4 (2011), (ADSL only), Bit 10 */
+   DSL_uint16_t E10 : 1;
+   /** L2 Automatic Exit (ADSL only), Bit 9 */
+   DSL_uint16_t E9 : 1;
+   /** L2 Low-Power Mode Enable (ADSL only), Bit 8 */
    DSL_uint16_t E8 : 1;
    /** Reserved */
    DSL_uint16_t Res1 : 5;
-   /** Loop Diagnostic Mode Control */
+   /** Loop Diagnostic Mode Control, Bit 2 */
    DSL_uint16_t E2 : 1;
    /** Reserved 0 */
    DSL_uint16_t E1 : 1;
-   /** Automatic Re-Start Control */
+   /** Automatic Re-Start Control, Bit 0 */
    DSL_uint16_t E0 : 1;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** L2 Low-Power Mode (ADSL only) */
-   FX_bit_t E8;
-   /** Reserved */
-   DSL_uint16_t Res0 : 7;
-   /** Automatic Re-Start Control */
+   /** Automatic Re-Start Control, Bit 0 */
    DSL_uint16_t E0 : 1;
    /** Reserved 0 */
    DSL_uint16_t E1 : 1;
-   /** Loop Diagnostic Mode Control */
+   /** Loop Diagnostic Mode Control, Bit 2 */
    DSL_uint16_t E2 : 1;
    /** Reserved */
    DSL_uint16_t Res1 : 5;
+   /** L2 Low-Power Mode Enable (ADSL only), Bit 8 */
+   DSL_uint16_t E8 : 1;
+   /** L2 Automatic Exit (ADSL only), Bit 9 */
+   DSL_uint16_t E9 : 1;
+   /** L2 Extensions of G.992.3 Amd4 (2011), (ADSL only), Bit 10 */
+   DSL_uint16_t E10 : 1;
+   /** Reserved */
+   DSL_uint16_t Res0 : 5;
 #endif
 } __PACKED__ ;
 
@@ -1073,7 +1255,9 @@ struct CMD_ModemFSM_Options2Set
    /** Length */
    DSL_uint16_t Length;
    /** Reserved */
-   DSL_uint16_t Res0 : 13;
+   DSL_uint16_t Res0 : 12;
+   /** AELEM Control (VDSL only), Bit 3 */
+   DSL_uint16_t enableAelem : 1;
    /** Short Init Control (ADSL only), Bit 2 */
    DSL_uint16_t shortInit : 1;
    /** US Virtual Noise Support, Bit 1 */
@@ -1091,8 +1275,10 @@ struct CMD_ModemFSM_Options2Set
    DSL_uint16_t enableVN_US : 1;
    /** Short Init Control (ADSL only), Bit 2 */
    DSL_uint16_t shortInit : 1;
+   /** AELEM Control (VDSL only), Bit 3 */
+   DSL_uint16_t enableAelem : 1;
    /** Reserved */
-   DSL_uint16_t Res0 : 13;
+   DSL_uint16_t Res0 : 12;
 #endif
 } __PACKED__ ;
 
@@ -1133,7 +1319,7 @@ struct CMD_ModemFSM_EventConfigure
    DSL_uint16_t Res0 : 1;
    /** Enable Bit 13 */
    DSL_uint16_t E13 : 1;
-   /** Enable Bit 13 */
+   /** Enable Bit 12 */
    DSL_uint16_t E12 : 1;
    /** Reserved */
    DSL_uint16_t Res1 : 1;
@@ -1192,7 +1378,7 @@ struct CMD_ModemFSM_EventConfigure
    DSL_uint16_t E11 : 1;
    /** Reserved */
    DSL_uint16_t Res1 : 1;
-   /** Enable Bit 13 */
+   /** Enable Bit 12 */
    DSL_uint16_t E12 : 1;
    /** Enable Bit 13 */
    DSL_uint16_t E13 : 1;
@@ -1394,9 +1580,9 @@ struct CMD_ReInitNE_Configure
    DSL_uint16_t E0 : 1;
    /** Reserved */
    DSL_uint16_t Res6 : 14;
-   /** ES90 */
+   /** ESx */
    DSL_uint16_t F1 : 1;
-   /** SES30 */
+   /** SESx */
    DSL_uint16_t F0 : 1;
 #else
    /** Index */
@@ -1431,9 +1617,9 @@ struct CMD_ReInitNE_Configure
    DSL_uint16_t E14 : 1;
    /** Reserved */
    DSL_uint16_t Res0 : 1;
-   /** SES30 */
+   /** SESx */
    DSL_uint16_t F0 : 1;
-   /** ES90 */
+   /** ESx */
    DSL_uint16_t F1 : 1;
    /** Reserved */
    DSL_uint16_t Res6 : 14;
@@ -1462,39 +1648,40 @@ struct ACK_ReInitNE_Configure
 
 
 /**
-   Triggers the sending of an L3 orderly shutdown request to the remote side.If
-   applied at the CPE and accepted by the CO, the following shall happen: The
-   CPE-Host forces L3 entry with transition to RESET state by applying
-   CMD_ModemFSM_StateGet.
+   Configuration of reinitialization trigger definitions.
 */
-struct CMD_L3ShutdownRequest
+struct CMD_ReinitThreshConfigure
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Reserved */
-   DSL_uint16_t Res0 : 15;
-   /** L3 Orderly Shutdown Request */
-   DSL_uint16_t L3shutdown : 1;
+   /** SESx Reinit Period */
+   DSL_uint16_t SESxPeriod;
+   /** LOM Persistency Time for Reinit */
+   DSL_uint16_t LomRiPeriod;
+   /** ESx Reinit Period */
+   DSL_uint16_t ESxPeriod;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** L3 Orderly Shutdown Request */
-   DSL_uint16_t L3shutdown : 1;
-   /** Reserved */
-   DSL_uint16_t Res0 : 15;
+   /** SESx Reinit Period */
+   DSL_uint16_t SESxPeriod;
+   /** LOM Persistency Time for Reinit */
+   DSL_uint16_t LomRiPeriod;
+   /** ESx Reinit Period */
+   DSL_uint16_t ESxPeriod;
 #endif
 } __PACKED__ ;
 
 
 /**
-   Acknowledgement for CMD_L3ShutdownRequest.
+   Acknowledgement for the message ACK_ReinitThreshConfigure.
 */
-struct ACK_L3ShutdownRequest
+struct ACK_ReinitThreshConfigure
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
@@ -1510,6 +1697,148 @@ struct ACK_L3ShutdownRequest
 } __PACKED__ ;
 
 
+/**
+   Triggers a shutdown request, either as "L3 orderly shutdown" towards the
+   remote side or as "locally forced shutdown" to the DSL-FW without sending a
+   request to the remote side.After an "L3 orderly shutdown" request was
+   accepted by the CO, the following shall happen: The CPE-Host forces L3 entry
+   with transition to RESET state by applying CMD_ModemFSM_StateGet.A "locally
+   forced shutdown" always results in exiting Showtime.
+*/
+struct CMD_ShutdownRequest
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
+   /** Locally Forced Shutdown */
+   DSL_uint16_t ForcedShutdown : 1;
+   /** L3 Orderly Shutdown Request */
+   DSL_uint16_t L3shutdown : 1;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** L3 Orderly Shutdown Request */
+   DSL_uint16_t L3shutdown : 1;
+   /** Locally Forced Shutdown */
+   DSL_uint16_t ForcedShutdown : 1;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Acknowledgement for CMD_ShutdownRequest.
+*/
+struct ACK_ShutdownRequest
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#endif
+} __PACKED__ ;
+
+
+/**
+   For a "locally forced shutdown" (see CMD_ShutdownRequest) the time is set
+   that the modem state machine will wait in PRE_FAIL state before entering FAIL
+   state.
+*/
+struct CMD_PrefailConfigure
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** PRE_FAIL Duration */
+   DSL_uint16_t PrefailTime;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** PRE_FAIL Duration */
+   DSL_uint16_t PrefailTime;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Acknowledgement for CMD_PrefailConfigure.
+*/
+struct ACK_PrefailConfigure
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Requests information about PRE_FAIL state data.
+*/
+struct CMD_PrefailDataGet
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Acknowledgement for CMD_PrefailDataGet. It provides information about
+   PRE_FAIL state data.
+*/
+struct ACK_PrefailDataGet
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** PDB RAM Acquirement Time */
+   DSL_uint16_t AquireTime;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** PDB RAM Acquirement Time */
+   DSL_uint16_t AquireTime;
+#endif
+} __PACKED__ ;
+
+
 /**
    Requests information about L3 orderly shutdown requests initiated from the
    remote side.Applying CMD_RxL3RequestStatusGet allows the host to determine
@@ -2077,19 +2406,155 @@ struct ACK_UPBO_KL0Get
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Kl0 Estimate VTU-O */
-   DSL_uint16_t kl0_EstimO;
    /** Kl0 Estimate VTU-R */
    DSL_uint16_t kl0_EstimR;
+   /** Kl0 Estimate VTU-O */
+   DSL_uint16_t kl0_EstimO;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Kl0 Estimate VTU-O */
-   DSL_uint16_t kl0_EstimO;
    /** Kl0 Estimate VTU-R */
    DSL_uint16_t kl0_EstimR;
+   /** Kl0 Estimate VTU-O */
+   DSL_uint16_t kl0_EstimO;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Requests status parameters for the Upstream  Power  Back-Off  (UPBO)
+   alternative  electrical  length  estimation  method (AELEM).
+*/
+struct CMD_PBO_AELEM_Status_Get
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Upstream  Power  Back-Off  (UPBO)  status  parameters  for  the  alternative
+   electrical  length  estimation  method (AELEM) are reported.
+*/
+struct ACK_PBO_AELEM_Status_Get
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** AELE-MODE Used */
+   DSL_uint16_t AeleMode;
+   /** Kl0 Estimate per Band VTU-R */
+   DSL_uint16_t Kl0EstimRPb[4];
+   /** Final Kl0 per Band VTU-O */
+   DSL_uint16_t Kl0EstimOPb[4];
+   /** UPBOELMT */
+   DSL_uint16_t UpboElmt;
+   /** RXTHRSHDS */
+   DSL_int16_t RxThreshDs;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** AELE-MODE Used */
+   DSL_uint16_t AeleMode;
+   /** Kl0 Estimate per Band VTU-R */
+   DSL_uint16_t Kl0EstimRPb[4];
+   /** Final Kl0 per Band VTU-O */
+   DSL_uint16_t Kl0EstimOPb[4];
+   /** UPBOELMT */
+   DSL_uint16_t UpboElmt;
+   /** RXTHRSHDS */
+   DSL_int16_t RxThreshDs;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Enables for each VDSL2 Profile an adaptive PSD optimization (ceiling)
+   algorithm. Currently only required for Profile 8b due to the high transmit
+   power.
+*/
+struct CMD_PSD_CeilingDS_Set
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t  Length;
+   /** Reserved */
+   DSL_uint8_t Res0;
+   /** Enable PSD Ceiling Optimization for Profile 30a */
+   DSL_uint16_t PSDCeil7 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 17a */
+   DSL_uint16_t PSDCeil6 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 12b */
+   DSL_uint16_t PSDCeil5 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 12a */
+   DSL_uint16_t PSDCeil4 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8d */
+   DSL_uint16_t PSDCeil3 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8c */
+   DSL_uint16_t PSDCeil2 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8b */
+   DSL_uint16_t PSDCeil1 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8a */
+   DSL_uint16_t PSDCeil0 : 1;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t  Length;
+   /** Enable PSD Ceiling Optimization for Profile 8a */
+   DSL_uint16_t PSDCeil0 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8b */
+   DSL_uint16_t PSDCeil1 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8c */
+   DSL_uint16_t PSDCeil2 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 8d */
+   DSL_uint16_t PSDCeil3 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 12a */
+   DSL_uint16_t PSDCeil4 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 12b */
+   DSL_uint16_t PSDCeil5 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 17a */
+   DSL_uint16_t PSDCeil6 : 1;
+   /** Enable PSD Ceiling Optimization for Profile 30a */
+   DSL_uint16_t PSDCeil7 : 1;
+   /** Reserved */
+   DSL_uint8_t Res0;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Acknowledgement for message CMD_PSD_CeilingDS_Set.
+*/
+struct ACK_PSD_CeilingDS_Set
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
 #endif
 } __PACKED__ ;
 
@@ -2157,7 +2622,7 @@ struct CMD_BearerCh0_DS_Set
    DSL_uint16_t Res0 : 13;
    /** Reserved (STM) */
    DSL_uint16_t Res1 : 1;
-   /** ATM Configuration Control (ADSL) */
+   /** ATM Configuration Control */
    DSL_uint16_t ATMControl : 1;
    /** PTM Configuration Control */
    DSL_uint16_t PTMControl : 1;
@@ -2212,7 +2677,7 @@ struct CMD_BearerCh0_DS_Set
    DSL_uint16_t Length;
    /** PTM Configuration Control */
    DSL_uint16_t PTMControl : 1;
-   /** ATM Configuration Control (ADSL) */
+   /** ATM Configuration Control */
    DSL_uint16_t ATMControl : 1;
    /** Reserved (STM) */
    DSL_uint16_t Res1 : 1;
@@ -2304,7 +2769,7 @@ struct CMD_BearerCh0_US_Set
    DSL_uint16_t Res0 : 13;
    /** Reserved (STM) */
    DSL_uint16_t Res1 : 1;
-   /** ATM Configuration Control (ADSL only) */
+   /** ATM Configuration Control */
    DSL_uint16_t ATMControl : 1;
    /** PTM Configuration Control */
    DSL_uint16_t PTMControl : 1;
@@ -2359,7 +2824,7 @@ struct CMD_BearerCh0_US_Set
    DSL_uint16_t Length;
    /** PTM Configuration Control */
    DSL_uint16_t PTMControl : 1;
-   /** ATM Configuration Control (ADSL only) */
+   /** ATM Configuration Control */
    DSL_uint16_t ATMControl : 1;
    /** Reserved (STM) */
    DSL_uint16_t Res1 : 1;
@@ -2567,39 +3032,39 @@ struct CMD_AlgorithmControlSet
    DSL_uint16_t Res1 : 1;
    /** Steady-State Algorithm Control, Bit8 */
    DSL_uint16_t SAC8 : 1;
-   /** Steady-State Algorithm Control, Bit7 */
-   DSL_uint16_t SAC7 : 1;
+   /** Reserved */
+   DSL_uint16_t Res2 : 1;
    /** Steady-State Algorithm Control, Bit6 */
    DSL_uint16_t SAC6 : 1;
    /** Reserved */
-   DSL_uint16_t Res2 : 1;
+   DSL_uint16_t Res3 : 1;
    /** Steady-State Algorithm Control, Bit4 */
    DSL_uint16_t SAC4 : 1;
    /** Reserved */
-   DSL_uint16_t Res3 : 2;
+   DSL_uint16_t Res4 : 2;
    /** Steady-State Algorithm Control, Bit1 */
    DSL_uint16_t SAC1 : 1;
    /** Reserved */
-   DSL_uint16_t Res4 : 1;
+   DSL_uint16_t Res5 : 1;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
    /** Reserved */
-   DSL_uint16_t Res4 : 1;
+   DSL_uint16_t Res5 : 1;
    /** Steady-State Algorithm Control, Bit1 */
    DSL_uint16_t SAC1 : 1;
    /** Reserved */
-   DSL_uint16_t Res3 : 2;
+   DSL_uint16_t Res4 : 2;
    /** Steady-State Algorithm Control, Bit4 */
    DSL_uint16_t SAC4 : 1;
    /** Reserved */
-   DSL_uint16_t Res2 : 1;
+   DSL_uint16_t Res3 : 1;
    /** Steady-State Algorithm Control, Bit6 */
    DSL_uint16_t SAC6 : 1;
-   /** Steady-State Algorithm Control, Bit7 */
-   DSL_uint16_t SAC7 : 1;
+   /** Reserved */
+   DSL_uint16_t Res2 : 1;
    /** Steady-State Algorithm Control, Bit8 */
    DSL_uint16_t SAC8 : 1;
    /** Reserved */
@@ -2646,11 +3111,17 @@ struct CMD_Misc_ConfigSet
    /** Length */
    DSL_uint16_t Length;
    /** Reserved */
-   DSL_uint16_t Res0 : 12;
+   DSL_uint16_t Res0 : 9;
+   /** Short CLR for ADSL2+ */
+   DSL_uint16_t ShortClrA2p : 1;
+   /** Short CLR for ADSL2 */
+   DSL_uint16_t ShortClrA2 : 1;
+   /** Short CLR for ADSL1 */
+   DSL_uint16_t ShortClrA1 : 1;
    /** INP Protection Improvement (VDSL only) */
    DSL_uint16_t FrameParams : 1;
-   /** Reserved */
-   DSL_uint16_t Res1 : 1;
+   /** LOS Criteria Control (VDSL only) */
+   DSL_uint16_t losCondition : 1;
    /** Activation Start Mode (ADSL only) */
    DSL_uint16_t StartMode : 1;
    /** Non-standard GHS-ANSI Activation (ADSL only) */
@@ -2664,12 +3135,18 @@ struct CMD_Misc_ConfigSet
    DSL_uint16_t GhsAnsiSeq : 1;
    /** Activation Start Mode (ADSL only) */
    DSL_uint16_t StartMode : 1;
-   /** Reserved */
-   DSL_uint16_t Res1 : 1;
+   /** LOS Criteria Control (VDSL only) */
+   DSL_uint16_t losCondition : 1;
    /** INP Protection Improvement (VDSL only) */
    DSL_uint16_t FrameParams : 1;
+   /** Short CLR for ADSL1 */
+   DSL_uint16_t ShortClrA1 : 1;
+   /** Short CLR for ADSL2 */
+   DSL_uint16_t ShortClrA2 : 1;
+   /** Short CLR for ADSL2+ */
+   DSL_uint16_t ShortClrA2p : 1;
    /** Reserved */
-   DSL_uint16_t Res0 : 12;
+   DSL_uint16_t Res0 : 9;
 #endif
 } __PACKED__ ;
 
@@ -2705,7 +3182,7 @@ struct CMD_OperationOptionsSet
    DSL_uint16_t Length;
    /** Reserved */
    DSL_uint16_t Res0 : 13;
-   /** VRX_ENABLE, Fixed value */
+   /** MFD (ADSL only) */
    DSL_uint16_t Mfd : 1;
    /** Enhanced Upstream Framing (ADSL-Only) */
    DSL_uint16_t UsFramingExt : 1;
@@ -2720,7 +3197,7 @@ struct CMD_OperationOptionsSet
    DSL_uint16_t Ntr : 1;
    /** Enhanced Upstream Framing (ADSL-Only) */
    DSL_uint16_t UsFramingExt : 1;
-   /** VRX_ENABLE, Fixed value */
+   /** MFD (ADSL only) */
    DSL_uint16_t Mfd : 1;
    /** Reserved */
    DSL_uint16_t Res0 : 13;
@@ -2748,48 +3225,33 @@ struct ACK_OperationOptionsSet
 
 
 /**
-   The message configures interoperability settings for ADSL.
+   The message selects a DSL operator. The information is used to configure
+   operator specific settings inside the DSL firmware.
 */
-struct CMD_InteropConfigSet
+struct CMD_OperatorSelect
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Reserved */
-   DSL_uint16_t Res0 : 10;
-   /** CRC/FEC Counter Restore On Showtime Entry, Bit 5 */
-   DSL_uint16_t cntRestore : 1;
-   /** Reserved */
-   DSL_uint16_t Res1 : 5;
-   /** Reserved */
-   DSL_uint16_t Res2 : 15;
-   /** PCB Level Adjustment, Bit 0 */
-   DSL_uint16_t pcbAdjust : 1;
+   /** DSL Operator Selection */
+   DSL_uint16_t DslOperator;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Reserved */
-   DSL_uint16_t Res1 : 5;
-   /** CRC/FEC Counter Restore On Showtime Entry, Bit 5 */
-   DSL_uint16_t cntRestore : 1;
-   /** Reserved */
-   DSL_uint16_t Res0 : 10;
-   /** PCB Level Adjustment, Bit 0 */
-   DSL_uint16_t pcbAdjust : 1;
-   /** Reserved */
-   DSL_uint16_t Res2 : 15;
+   /** DSL Operator Selection */
+   DSL_uint16_t DslOperator;
 #endif
 } __PACKED__ ;
 
 
 /**
-   This is the acknowledgement for CMD_InteropConfigSet.
+   This is the acknowledgement for ACK_OperatorSelect.
 */
-struct ACK_InteropConfigSet
+struct ACK_OperatorSelect
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
@@ -2806,59 +3268,51 @@ struct ACK_InteropConfigSet
 
 
 /**
-   The message requests the interoperability settings.
+   The messages configures settings for test modes.
 */
-struct CMD_InteropConfigGet
+struct CMD_TestOptionsSet
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
+   /** US Finegain Control */
+   DSL_uint16_t FgainControlUs : 1;
+   /** DS Finegain Control */
+   DSL_uint16_t FgainControlDs : 1;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
+   /** DS Finegain Control */
+   DSL_uint16_t FgainControlDs : 1;
+   /** US Finegain Control */
+   DSL_uint16_t FgainControlUs : 1;
+   /** Reserved */
+   DSL_uint16_t Res0 : 14;
 #endif
 } __PACKED__ ;
 
 
 /**
-   This is the acknowledgement for CMD_InteropConfigGet.
+   This is the acknowledgement for CMD_TestOptionsSet.
 */
-struct ACK_InteropConfigGet
+struct ACK_TestOptionsSet
 {
 #if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Reserved */
-   DSL_uint16_t Res0 : 10;
-   /** CRC/FEC Counter Restore On Showtime Entry, Bit 5 */
-   DSL_uint16_t cntRestore : 1;
-   /** Reserved */
-   DSL_uint16_t Res1 : 5;
-   /** Reserved */
-   DSL_uint16_t Res2 : 15;
-   /** PCB Level Adjustment, Bit 0 */
-   DSL_uint16_t pcbAdjust : 1;
 #else
    /** Index */
    DSL_uint16_t Index;
    /** Length */
    DSL_uint16_t Length;
-   /** Reserved */
-   DSL_uint16_t Res1 : 5;
-   /** CRC/FEC Counter Restore On Showtime Entry, Bit 5 */
-   DSL_uint16_t cntRestore : 1;
-   /** Reserved */
-   DSL_uint16_t Res0 : 10;
-   /** PCB Level Adjustment, Bit 0 */
-   DSL_uint16_t pcbAdjust : 1;
-   /** Reserved */
-   DSL_uint16_t Res2 : 15;
 #endif
 } __PACKED__ ;
 
