@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2012
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -57,6 +56,22 @@ typedef struct CMD_CounterControlSet CMD_CounterControlSet_t;
 */
 typedef struct ACK_CounterControlSet ACK_CounterControlSet_t;
 
+/** Message ID for CMD_PM_OptionsSet */
+#define CMD_PM_OPTIONSSET 0x1662
+
+/**
+   Configures options for performance monitoring functions.
+*/
+typedef struct CMD_PM_OptionsSet CMD_PM_OptionsSet_t;
+
+/** Message ID for ACK_PM_OptionsSet */
+#define ACK_PM_OPTIONSSET 0x1662
+
+/**
+   Acknowledgement for message ACK_PM_OptionsSet.
+*/
+typedef struct ACK_PM_OptionsSet ACK_PM_OptionsSet_t;
+
 /** Message ID for ALM_LineFailureNE_Get */
 #define ALM_LINEFAILURENE_GET 0x0007
 
@@ -178,9 +193,10 @@ typedef struct CMD_CRC_StatsNE_Get CMD_CRC_StatsNE_Get_t;
 #define ACK_CRC_STATSNE_GET 0x080A
 
 /**
-   Returns near-end CRC counter values. (Section 7.2.2.1.1 of G997.1). These are
-   wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Returns near-end CRC counter values. (Section 7.2.2.1.1 of G.997.1). These
+   are wrap-around counters which are not affected by the TR1-period.The
+   "LP1/Fast Path" parameters are fed only in ADSL1 mode with selected fast
+   path.
 */
 typedef struct ACK_CRC_StatsNE_Get ACK_CRC_StatsNE_Get_t;
 
@@ -197,7 +213,7 @@ typedef struct CMD_CRC_StatsFE_Get CMD_CRC_StatsFE_Get_t;
 #define ACK_CRC_STATSFE_GET 0x0C0A
 
 /**
-   Returns far-end CRC counter values. (Section 7.2.2.2.1 of G997.1). These are
+   Returns far-end CRC counter values. (Section 7.2.2.2.1 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -216,7 +232,7 @@ typedef struct CMD_FEC_StatsNE_Get CMD_FEC_StatsNE_Get_t;
 #define ACK_FEC_STATSNE_GET 0x0A0A
 
 /**
-   Returns near-end FEC counter values (Section 7.2.2.1.2 of G997.1). These are
+   Returns near-end FEC counter values (Section 7.2.2.1.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -235,7 +251,7 @@ typedef struct CMD_FEC_StatsFE_Get CMD_FEC_StatsFE_Get_t;
 #define ACK_FEC_STATSFE_GET 0x0E0A
 
 /**
-   Returns far-end FEC counter values (Section 7.2.2.2.2 of G997.1). These are
+   Returns far-end FEC counter values (Section 7.2.2.2.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -253,7 +269,7 @@ typedef struct CMD_SOS_StatsNE_Get CMD_SOS_StatsNE_Get_t;
 #define ACK_SOS_STATSNE_GET 0x290A
 
 /**
-   Returns near-end SOS counter values. (Section 7.2.1.6.1 of G997.1)
+   Returns near-end SOS counter values. (Section 7.2.1.6.1 of G.997.1)
 */
 typedef struct ACK_SOS_StatsNE_Get ACK_SOS_StatsNE_Get_t;
 
@@ -270,7 +286,7 @@ typedef struct CMD_SOS_StatsFE_Get CMD_SOS_StatsFE_Get_t;
 #define ACK_SOS_STATSFE_GET 0x2A0A
 
 /**
-   Returns far-end SOS counter values. (Section 7.2.1.7.1 of G997.1)
+   Returns far-end SOS counter values. (Section 7.2.1.7.1 of G.997.1)
 */
 typedef struct ACK_SOS_StatsFE_Get ACK_SOS_StatsFE_Get_t;
 
@@ -295,14 +311,14 @@ typedef struct ACK_LinePerfCountNE_Set ACK_LinePerfCountNE_Set_t;
 #define CMD_CRC_STATSNE_SET 0x084A
 
 /**
-   Writes the near-end CRC counter values (Section 7.2.2.1.1 of G997.1)The
+   Writes the near-end CRC counter values (Section 7.2.2.1.1 of G.997.1)The
    "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
    Path".
 */
 typedef struct CMD_CRC_StatsNE_Set CMD_CRC_StatsNE_Set_t;
 
 /** Message ID for ACK_CRC_StatsNE_Set */
-#define ACK_CRC_STATSNE_SET 0x094A
+#define ACK_CRC_STATSNE_SET 0x084A
 
 /**
    Acknowledgement for the message CMD_CRC_StatsNE_Set.
@@ -310,17 +326,17 @@ typedef struct CMD_CRC_StatsNE_Set CMD_CRC_StatsNE_Set_t;
 typedef struct ACK_CRC_StatsNE_Set ACK_CRC_StatsNE_Set_t;
 
 /** Message ID for CMD_FEC_StatsNE_Set */
-#define CMD_FEC_STATSNE_SET 0x0B4A
+#define CMD_FEC_STATSNE_SET 0x0A4A
 
 /**
-   Writes near-end FEC counter values. (Section 7.2.2.1.2 of G997.1)The
+   Writes near-end FEC counter values. (Section 7.2.2.1.2 of G.997.1)The
    "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
    Path".
 */
 typedef struct CMD_FEC_StatsNE_Set CMD_FEC_StatsNE_Set_t;
 
 /** Message ID for ACK_FEC_StatsNE_Set */
-#define ACK_FEC_STATSNE_SET 0x0B4A
+#define ACK_FEC_STATSNE_SET 0x0A4A
 
 /**
    Acknowledgement for the message CMD_FEC_StatsNE_Set.
@@ -332,7 +348,7 @@ typedef struct ACK_FEC_StatsNE_Set ACK_FEC_StatsNE_Set_t;
 
 /**
    Writes near-end SOS counter values. ("SOS-SUCCESS-NE", Section 7.2.1.6.1 of
-   G997.1).
+   G.997.1).
 */
 typedef struct  CMD_SOS_StatsNE_Set CMD_SOS_StatsNE_Set_t;
 
@@ -427,6 +443,52 @@ struct ACK_CounterControlSet
 } __PACKED__ ;
 
 
+/**
+   Configures options for performance monitoring functions.
+*/
+struct CMD_PM_OptionsSet
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** Reserved */
+   DSL_uint16_t Res0 : 15;
+   /** Supress CRC/FEC Counter-Writeback (ADSL only) */
+   DSL_uint16_t CrcFecWrProtect : 1;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+   /** Supress CRC/FEC Counter-Writeback (ADSL only) */
+   DSL_uint16_t CrcFecWrProtect : 1;
+   /** Reserved */
+   DSL_uint16_t Res0 : 15;
+#endif
+} __PACKED__ ;
+
+
+/**
+   Acknowledgement for message ACK_PM_OptionsSet.
+*/
+struct ACK_PM_OptionsSet
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#else
+   /** Index */
+   DSL_uint16_t Index;
+   /** Length */
+   DSL_uint16_t Length;
+#endif
+} __PACKED__ ;
+
+
 /**
    This autonomous message indicates near-end line failures.
 */
@@ -888,9 +950,10 @@ struct CMD_CRC_StatsNE_Get
 
 
 /**
-   Returns near-end CRC counter values. (Section 7.2.2.1.1 of G997.1). These are
-   wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Returns near-end CRC counter values. (Section 7.2.2.1.1 of G.997.1). These
+   are wrap-around counters which are not affected by the TR1-period.The
+   "LP1/Fast Path" parameters are fed only in ADSL1 mode with selected fast
+   path.
 */
 struct ACK_CRC_StatsNE_Get
 {
@@ -945,7 +1008,7 @@ struct CMD_CRC_StatsFE_Get
 
 
 /**
-   Returns far-end CRC counter values. (Section 7.2.2.2.1 of G997.1). These are
+   Returns far-end CRC counter values. (Section 7.2.2.2.1 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -1002,7 +1065,7 @@ struct CMD_FEC_StatsNE_Get
 
 
 /**
-   Returns near-end FEC counter values (Section 7.2.2.1.2 of G997.1). These are
+   Returns near-end FEC counter values (Section 7.2.2.1.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -1091,7 +1154,7 @@ struct CMD_FEC_StatsFE_Get
 
 
 /**
-   Returns far-end FEC counter values (Section 7.2.2.2.2 of G997.1). These are
+   Returns far-end FEC counter values (Section 7.2.2.2.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
    Path" parameters are fed only in ADSL1 mode with selected fast path.
 */
@@ -1167,7 +1230,7 @@ struct CMD_SOS_StatsNE_Get
 
 
 /**
-   Returns near-end SOS counter values. (Section 7.2.1.6.1 of G997.1)
+   Returns near-end SOS counter values. (Section 7.2.1.6.1 of G.997.1)
 */
 struct ACK_SOS_StatsNE_Get
 {
@@ -1214,7 +1277,7 @@ struct CMD_SOS_StatsFE_Get
 
 
 /**
-   Returns far-end SOS counter values. (Section 7.2.1.7.1 of G997.1)
+   Returns far-end SOS counter values. (Section 7.2.1.7.1 of G.997.1)
 */
 struct ACK_SOS_StatsFE_Get
 {
@@ -1320,7 +1383,7 @@ struct ACK_LinePerfCountNE_Set
 
 
 /**
-   Writes the near-end CRC counter values (Section 7.2.2.1.1 of G997.1)The
+   Writes the near-end CRC counter values (Section 7.2.2.1.1 of G.997.1)The
    "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
    Path".
 */
@@ -1376,7 +1439,7 @@ struct ACK_CRC_StatsNE_Set
 
 
 /**
-   Writes near-end FEC counter values. (Section 7.2.2.1.2 of G997.1)The
+   Writes near-end FEC counter values. (Section 7.2.2.1.2 of G.997.1)The
    "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
    Path".
 */
@@ -1465,7 +1528,7 @@ struct ACK_FEC_StatsNE_Set
 
 /**
    Writes near-end SOS counter values. ("SOS-SUCCESS-NE", Section 7.2.1.6.1 of
-   G997.1).
+   G.997.1).
 */
 struct  CMD_SOS_StatsNE_Set
 {
