@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                               Copyright (c) 2012
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -40,6 +39,8 @@ DSL_Error_t DSL_DRV_PM_DEV_Start(DSL_Context_t *pContext)
    DSL_DRV_PM_CONTEXT(pContext)->nCurrShowtime = DSL_PM_FWMODE_NA;
 
 #ifdef INCLUDE_DSL_CPE_PM_CONFIG
+   memset(&pmCfg, 0x0, sizeof(DSL_PM_ConfigData_t));
+
    /* Get PM module configuration data*/
    memcpy(&pmCfg, &(DSL_DRV_PM_CONTEXT(pContext)->nPmConfig),
       sizeof(DSL_PM_ConfigData_t));
@@ -76,6 +77,8 @@ DSL_Error_t DSL_DRV_PM_DEV_Restart(DSL_Context_t *pContext)
 #endif /* INCLUDE_DSL_CPE_PM_CONFIG*/
 
 #ifdef INCLUDE_DSL_CPE_PM_CONFIG
+   memset(&pmCfg, 0x0, sizeof(DSL_PM_ConfigData_t));
+
    /* Get PM module configuration data*/
    memcpy(&pmCfg, &(DSL_DRV_PM_CONTEXT(pContext)->nPmConfig),
       sizeof(DSL_PM_ConfigData_t));
@@ -98,9 +101,9 @@ DSL_Error_t DSL_DRV_PM_DEV_Restart(DSL_Context_t *pContext)
 
    /* Allow counters polling if the current FW binary mode equals to the
       Last Showtime mode*/
-   if( ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2)) &&
+   if( ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_VDSL)) ||
-       ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL)) &&
+       ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_ADSL)) )
    {
       /* Set bPmDataValid flag*/
@@ -127,55 +130,6 @@ DSL_Error_t DSL_DRV_PM_DEV_Suspend(DSL_Context_t *pContext)
    return nErrCode;
 }
 
-DSL_Error_t DSL_DRV_PM_DEV_ShowtimeReachedHandle(DSL_Context_t *pContext)
-{
-   DSL_Error_t nErrCode = DSL_SUCCESS;
-#ifdef INCLUDE_DSL_CPE_PM_CHANNEL_COUNTERS
-   CMD_InteropConfigGet_t sCmd;
-   ACK_InteropConfigGet_t sAck;
-
-   if ( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2))
-   {
-      /* Check for the Channel counters reset not need*/
-      return DSL_SUCCESS;
-   }
-
-   memset(&sCmd, 0x0, sizeof(sCmd));
-
-   sCmd.Index  = 0x1;
-   sCmd.Length = 0x1;
-
-   /* Get Interop status*/
-   nErrCode = DSL_DRV_VRX_SendMessage(
-                 pContext,
-                 CMD_INTEROPCONFIGGET,
-                 sizeof(sCmd), (DSL_uint8_t*)&(sCmd),
-                 sizeof(sAck), (DSL_uint8_t*)&(sAck));
-
-   if (nErrCode != DSL_SUCCESS)
-   {
-      DSL_DEBUG( DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Interop Status get failed!"
-         DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-      return nErrCode;
-   }
-
-   /* Check for the Channel counters FW autonomous reset*/
-   if ( sAck.cntRestore == VRX_DISABLE )
-   {
-      /* Set bNeChannelCntReset flag. Flag will be cleared on the 1st
-         Channel Counters FW access*/
-      DSL_DRV_PM_CONTEXT(pContext)->bNeChannelCntReset = DSL_TRUE;
-
-      DSL_DEBUG( DSL_DBG_MSG,
-         (pContext, SYS_DBG_MSG"DSL[%02d]: FW channel counters autonomous reset is enabled"
-         DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-   }
-#endif /* INCLUDE_DSL_CPE_PM_CHANNEL_COUNTERS*/
-
-   return nErrCode;
-}
-
 /*
    For a detailed description of the function, its arguments and return value
    please refer to the description in the header file 'drv_dsl_cpe_device_pm.h'
@@ -184,11 +138,11 @@ DSL_Error_t DSL_DRV_PM_DEV_OnEapsTimeout(DSL_Context_t *pContext)
 {
    DSL_Error_t nErrCode = DSL_SUCCESS;
 
-   if (DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2))
+   if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2))
    {
       DSL_DRV_PM_CONTEXT(pContext)->nCurrShowtime = DSL_PM_FWMODE_VDSL;
    }
-   else if (DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL))
+   else if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL))
    {
       DSL_DRV_PM_CONTEXT(pContext)->nCurrShowtime = DSL_PM_FWMODE_ADSL;
    }
@@ -341,171 +295,87 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersGet(
       ACK_FEC_StatsFE_Get_t FecStatsFE;
    } sAck;
 
-   DSL_PM_ChannelData_t *pCurrCounters = DSL_NULL;
-
    DSL_CHECK_POINTER(pContext, pCounters);
    DSL_CHECK_ATU_DIRECTION(nDirection);
    DSL_CHECK_ERR_CODE();
 
-   DSL_DEBUG( DSL_DBG_MSG,
-      (pContext, SYS_DBG_MSG"DSL[%02d]: IN - DSL_DRV_PM_DEV_ChannelCountersCurrentGet, (nDirection=%s, nChannel=%d)"
-      DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nDirection==DSL_NEAR_END ? "NE":"FE", nChannel));
+   DSL_DEBUG( DSL_DBG_MSG, (pContext, SYS_DBG_MSG
+      "DSL[%02d]: IN - DSL_DRV_PM_DEV_ChannelCountersCurrentGet, "
+      "(nDirection=%s, nChannel=%d)"DSL_DRV_CRLF,
+      DSL_DEV_NUM(pContext), nDirection==DSL_NEAR_END ? "NE":"FE", nChannel));
 
    /* Reset the output structure*/
    memset(pCounters, 0x0, sizeof(DSL_PM_ChannelData_t));
 
-   if( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2) )
-   {
-   /*... VDSL only mode*/
-      memset(&(sAck.CrcStatsNE), 0x0, sizeof(sAck.CrcStatsNE));
-
-      sCmd.CrcStatsFE.Index  = sCmd.CrcStatsNE.Index  = 0x0;
-      sCmd.CrcStatsFE.Length = sCmd.CrcStatsNE.Length = 4;
-
-      /* Get Code Violations*/
-      nErrCode = DSL_DRV_VRX_SendMessage(
-         pContext,
-         nDirection == DSL_NEAR_END ? CMD_CRC_STATSNE_GET: CMD_CRC_STATSFE_GET,
-         sizeof(sCmd.CrcStatsNE), (DSL_uint8_t*)&(sCmd.CrcStatsNE),
-         sizeof(sAck.CrcStatsNE), (DSL_uint8_t*)&(sAck.CrcStatsNE));
-
-      /* Check nErrCode and return on error*/
-      if( nErrCode < 0 )
-      {
-         DSL_DEBUG( DSL_DBG_ERR,
-            (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Code Violations statistics"
-             " Get failed!"DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-
-         return nErrCode;
-      }
-
-      /* ACKs for the CMD_CRC_STATSNE_GET and CMD_CRC_STATSFE_GET have the
-          same strucrure, so we can use any*/
-      pCounters->nCodeViolations = (DSL_uint32_t)sAck.CrcStatsNE.cntCVI_LSW |
-                            (((DSL_uint32_t)sAck.CrcStatsNE.cntCVI_MSW) << 16);
-
-      memset(&(sAck.FecStatsNE), 0x0, sizeof(sAck.FecStatsNE));
-
-      sCmd.FecStatsFE.Index  = sCmd.FecStatsNE.Index  = 0x0;
-      sCmd.FecStatsFE.Length = sCmd.FecStatsNE.Length = 12;
-
-      /* Get Forward Error Corrections*/
-      nErrCode = DSL_DRV_VRX_SendMessage(
-         pContext,
-         nDirection == DSL_NEAR_END ? CMD_FEC_STATSNE_GET: CMD_FEC_STATSFE_GET,
-         sizeof(sCmd.FecStatsNE), (DSL_uint8_t*)&(sCmd.FecStatsNE),
-         sizeof(sAck.FecStatsNE), (DSL_uint8_t*)&(sAck.FecStatsNE));
-
-      /* Check nErrCode and return on error*/
-      if( nErrCode < 0 )
-      {
-         DSL_DEBUG( DSL_DBG_ERR,
-            (pContext,SYS_DBG_ERR"DSL[%02d]: ERROR - Forward Error Corrections"
-            " statistics Get failed!" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-
-         return nErrCode;
-      }
-
-      /* ACKs for the CMD_FEC_STATSNE_GET and CMD_FEC_STATSFE_GET have the
-          same strucrure, so we can use any*/
-      pCounters->nFEC = (DSL_uint32_t)sAck.FecStatsNE.cntECI_LSW |
-                      (((DSL_uint32_t)sAck.FecStatsNE.cntECI_MSW) << 16);
-   }
-   else if(DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL))
-   {
    /*... ADSL only mode*/
-      memset(&(sAck.CrcStatsNE), 0x0, sizeof(sAck.CrcStatsNE));
+   memset(&(sAck.CrcStatsNE), 0x0, sizeof(sAck.CrcStatsNE));
 
-      sCmd.CrcStatsNE.Index  = 0x0;
-      sCmd.CrcStatsNE.Length = 4;
+   sCmd.CrcStatsFE.Index  = sCmd.CrcStatsNE.Index  = 0x0;
+   sCmd.CrcStatsFE.Length = sCmd.CrcStatsNE.Length = 4;
 
+   /* skip fw exchange during training */
+   if (pContext->bGotShowtime)
+   {
       /* Get Code Violations*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_CRC_STATSNE_GET : CMD_CRC_STATSFE_GET,
          sizeof(sCmd.CrcStatsNE), (DSL_uint8_t*)&(sCmd.CrcStatsNE),
          sizeof(sAck.CrcStatsNE), (DSL_uint8_t*)&(sAck.CrcStatsNE));
+   }
 
-      /* Check nErrCode and return on error*/
-      if( nErrCode < 0 )
-      {
-         DSL_DEBUG( DSL_DBG_ERR,
-           (pContext,SYS_DBG_ERR"DSL[%02d]: ERROR - Code Violations statistics"
-               " get failed!" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+   /* Check nErrCode and return on error*/
+   if( nErrCode < 0 )
+   {
+      DSL_DEBUG( DSL_DBG_ERR,
+        (pContext,SYS_DBG_ERR"DSL[%02d]: ERROR - Code Violations statistics"
+            " get failed!" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
-         return nErrCode;
-      }
+      return nErrCode;
+   }
 
-      /* ACKs for the CMD_CRC_STATSNE_GET and CMD_CRC_STATSFE_GET have the
-          same strucrure, so we can use any*/
-      pCounters->nCodeViolations = (DSL_uint32_t)sAck.CrcStatsNE.cntCVI_LSW |
-                            (((DSL_uint32_t)sAck.CrcStatsNE.cntCVI_MSW) << 16);
+   /* ACKs for the CMD_CRC_STATSNE_GET and CMD_CRC_STATSFE_GET have the
+       same strucrure, so we can use any*/
+   pCounters->nCodeViolations = (DSL_uint32_t)sAck.CrcStatsNE.cntCVI_LSW |
+                         (((DSL_uint32_t)sAck.CrcStatsNE.cntCVI_MSW) << 16);
 
-      pCounters->nCodeViolations += (DSL_uint32_t)sAck.CrcStatsNE.cntCVF_LSW |
-                            (((DSL_uint32_t)sAck.CrcStatsNE.cntCVF_MSW) << 16);
+   pCounters->nCodeViolations += (DSL_uint32_t)sAck.CrcStatsNE.cntCVF_LSW |
+                         (((DSL_uint32_t)sAck.CrcStatsNE.cntCVF_MSW) << 16);
 
-      memset(&(sAck.FecStatsNE), 0x0, sizeof(sAck.FecStatsNE));
+   memset(&(sAck.FecStatsNE), 0x0, sizeof(sAck.FecStatsNE));
 
-      sCmd.FecStatsNE.Index  = 0x0;
-      sCmd.FecStatsNE.Length = 12;
+   sCmd.FecStatsFE.Index  = sCmd.FecStatsNE.Index  = 0x0;
+   sCmd.FecStatsFE.Length = sCmd.FecStatsNE.Length = 12;
 
+   /* skip fw exchange during training */
+   if (pContext->bGotShowtime)
+   {
       /* Get Forward Error Corrections*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_FEC_STATSNE_GET : CMD_FEC_STATSFE_GET,
          sizeof(sCmd.FecStatsNE), (DSL_uint8_t*)&(sCmd.FecStatsNE),
          sizeof(sAck.FecStatsNE), (DSL_uint8_t*)&(sAck.FecStatsNE));
-
-      /* Check nErrCode and return on error*/
-      if( nErrCode < 0 )
-      {
-         DSL_DEBUG( DSL_DBG_ERR,
-            (pContext,SYS_DBG_ERR"DSL[%02d]: ERROR - Forward Error Corrections"
-               " statistics get failed!" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-
-         return nErrCode;
-      }
-
-      /* ACKs for the CMD_FEC_STATSNE_GET and CMD_FEC_STATSFE_GET have the
-          same strucrure, so we can use any*/
-      pCounters->nFEC = (DSL_uint32_t)sAck.FecStatsNE.cntECI_LSW |
-                      (((DSL_uint32_t)sAck.FecStatsNE.cntECI_MSW) << 16);
-
-      pCounters->nFEC += (DSL_uint32_t)sAck.FecStatsNE.cntECF_CW_LSW |
-                       (((DSL_uint32_t)sAck.FecStatsNE.cntECF_CW_MSW) << 16);
-
-      /* Check for the NE counters FW autonomous reset*/
-      if ((DSL_DRV_PM_CONTEXT(pContext)->bNeChannelCntReset == DSL_TRUE) &&
-          (nDirection == DSL_NEAR_END))
-      {
-         /* Reset bNeChannelCntReset flag*/
-         DSL_DRV_PM_CONTEXT(pContext)->bNeChannelCntReset = DSL_FALSE;
-
-         /* Get pointer to the current channel counters*/
-         pCurrCounters = DSL_DRV_PM_PTR_CHANNEL_COUNTERS_CURR(nChannel,nDirection);
-         if (pCurrCounters == DSL_NULL)
-         {
-            nErrCode = DSL_ERR_INTERNAL;
-         }
-         else
-         {
-            DSL_DEBUG( DSL_DBG_MSG,
-               (pContext, SYS_DBG_MSG"DSL[%02d]: Channel reference counters reset due to the enabled"
-               " FW autonomous reset" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-
-            /* Reset current (reference) values*/
-            pCurrCounters->nFEC = 0;
-            pCurrCounters->nCodeViolations = 0;
-         }
-      }
    }
-   else
+
+   /* Check nErrCode and return on error*/
+   if( nErrCode < 0 )
    {
-     DSL_DEBUG( DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Unknown operation mode!"
-         DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+      DSL_DEBUG( DSL_DBG_ERR,
+         (pContext,SYS_DBG_ERR"DSL[%02d]: ERROR - Forward Error Corrections"
+            " statistics get failed!" DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+      return nErrCode;
    }
 
+   /* ACKs for the CMD_FEC_STATSNE_GET and CMD_FEC_STATSFE_GET have the
+       same strucrure, so we can use any*/
+   pCounters->nFEC = (DSL_uint32_t)sAck.FecStatsNE.cntECI_LSW |
+                   (((DSL_uint32_t)sAck.FecStatsNE.cntECI_MSW) << 16);
+
+   pCounters->nFEC += (DSL_uint32_t)sAck.FecStatsNE.cntECF_CW_LSW |
+                    (((DSL_uint32_t)sAck.FecStatsNE.cntECF_CW_MSW) << 16);
+
    DSL_DEBUG( DSL_DBG_MSG,
       (pContext, SYS_DBG_MSG"DSL[%02d]: OUT - DSL_PM_DEV_ChannelCountersCurrentGet"
       DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
@@ -555,12 +425,12 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersSet(
 
    /* Restore counters only if the last showtime FW mode equals to the
       current loaded FW binary*/
-   if( ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2)) &&
+   if( ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_VDSL)) ||
-       ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL)) &&
+       ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_ADSL)) )
    {
-      if( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2) )
+      if( DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2) )
       {
          memset(&(sCmd.CrcStatsNE), 0x0, sizeof(sCmd.CrcStatsNE));
 
@@ -568,10 +438,10 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersSet(
          sCmd.CrcStatsNE.Length = 4;
 
          /* Fill the LSW of the nCodeViolations counter*/
-         sCmd.CrcStatsNE.cntCVI_LSW = 
+         sCmd.CrcStatsNE.cntCVI_LSW =
                            (DSL_uint16_t)(pCounters->nCodeViolations & 0xFFFF);
          /* Fill the MSW of the nCodeViolations counter*/
-         sCmd.CrcStatsNE.cntCVI_MSW = 
+         sCmd.CrcStatsNE.cntCVI_MSW =
                    (DSL_uint16_t)((pCounters->nCodeViolations >> 16) & 0xFFFF);
 
          /* Set Code Violations*/
@@ -595,10 +465,10 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersSet(
          sCmd.FecStatsNE.Length = 12;
 
          /* Fill the LSW of the nFEC counter*/
-         sCmd.FecStatsNE.cntECI_LSW = 
+         sCmd.FecStatsNE.cntECI_LSW =
                                       (DSL_uint16_t)(pCounters->nFEC & 0xFFFF);
          /* Fill the MSW of the nFEC counter*/
-         sCmd.FecStatsNE.cntECI_MSW = 
+         sCmd.FecStatsNE.cntECI_MSW =
                               (DSL_uint16_t)((pCounters->nFEC >> 16) & 0xFFFF);
 
          /* Set FEC*/
@@ -624,10 +494,10 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersSet(
          sCmd.CrcStatsNE.Length = 4;
 
          /* Fill the LSW of the nCodeViolations counter*/
-         sCmd.CrcStatsNE.cntCVI_LSW = 
+         sCmd.CrcStatsNE.cntCVI_LSW =
                            (DSL_uint16_t)(pCounters->nCodeViolations & 0xFFFF);
          /* Fill the MSW of the nCodeViolations counter*/
-         sCmd.CrcStatsNE.cntCVI_MSW = 
+         sCmd.CrcStatsNE.cntCVI_MSW =
                    (DSL_uint16_t)((pCounters->nCodeViolations >> 16) & 0xFFFF);
 
          /* Set Code Violations*/
@@ -651,10 +521,10 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersSet(
          sCmd.FecStatsNE.Length = 12;
 
          /* Fill the LSW of the nFEC counter*/
-         sCmd.FecStatsNE.cntECI_LSW = 
+         sCmd.FecStatsNE.cntECI_LSW =
                                       (DSL_uint16_t)(pCounters->nFEC & 0xFFFF);
          /* Fill the MSW of the nFEC counter*/
-         sCmd.FecStatsNE.cntECI_MSW = 
+         sCmd.FecStatsNE.cntECI_MSW =
                               (DSL_uint16_t)((pCounters->nFEC >> 16) & 0xFFFF);
 
          /* Set FEC*/
@@ -704,14 +574,16 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
    union
    {
       CMD_PTM_BC0_StatsNE_Get_t   cmdPtmStatsGet;
-      CMD_ATM_BC0_StatsNE_Get_t   cmdAtmStatsGet;
+      CMD_ATM_BC0_StatsNE_Get_t   cmdAtmStatsNE_Get;
+      CMD_ATM_BC0_StatsFE_Get_t   cmdAtmStatsFE_Get;
       CMD_ATM_BC0_TxStatsNE_Get_t cmdAtmTxStatsGet;
    } sCmd;
 
    union
    {
       ACK_PTM_BC0_StatsNE_Get_t   ackPtmStatsGet;
-      ACK_ATM_BC0_StatsNE_Get_t   ackAtmStatsGet;
+      ACK_ATM_BC0_StatsNE_Get_t   ackAtmStatsNE_Get;
+      ACK_ATM_BC0_StatsFE_Get_t   ackAtmStatsFE_Get;
       ACK_ATM_BC0_TxStatsNE_Get_t ackAtmTxStatsGet;
    } sAck;
 
@@ -730,20 +602,26 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
    memset(pCounters, 0x0, sizeof(DSL_PM_DataPathData_t));
 
    /* not for ADSL-only mode */
-   if (DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2))
+   if ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2))
+      || (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL)))
    {
       if( nDirection == DSL_NEAR_END )
       {
+         /* PTM counters */
          memset(&(sAck.ackPtmStatsGet), 0x0, sizeof(sAck.ackPtmStatsGet));
 
          sCmd.cmdPtmStatsGet.Index  = 0x0;
          sCmd.cmdPtmStatsGet.Length = 8;
 
-         /* Get PTM statistics*/
-         nErrCode = DSL_DRV_VRX_SendMessage(
-            pContext, CMD_PTM_BC0_STATSNE_GET,
-            sizeof(sCmd.cmdPtmStatsGet), (DSL_uint8_t*)&(sCmd.cmdPtmStatsGet),
-            sizeof(sAck.ackPtmStatsGet), (DSL_uint8_t*)&(sAck.ackPtmStatsGet));
+         /* skip fw exchange during training */
+         if (pContext->bGotShowtime)
+         {
+            /* Get PTM statistics*/
+            nErrCode = DSL_DRV_VRX_SendMessage(
+               pContext, CMD_PTM_BC0_STATSNE_GET,
+               sizeof(sCmd.cmdPtmStatsGet), (DSL_uint8_t*)&(sCmd.cmdPtmStatsGet),
+               sizeof(sAck.ackPtmStatsGet), (DSL_uint8_t*)&(sAck.ackPtmStatsGet));
+         }
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -761,29 +639,22 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
 
          pCounters->nCRC_P  = (sAck.ackPtmStatsGet.cntCRC_MSW << 16) | sAck.ackPtmStatsGet.cntCRC_LSW;
          pCounters->nCV_P   = (sAck.ackPtmStatsGet.cntCV_MSW << 16) | sAck.ackPtmStatsGet.cntCV_LSW;
-      }
-      else
-      {
-         DSL_DEBUG( DSL_DBG_WRN,
-            (pContext, SYS_DBG_WRN"DSL[%02d]: WARNING - Data Path counters are not supported for the VDSL FE!"
-            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-      }
-   }
-   else if (DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL))
-   {
-   /*... not for VDSL-only mode */
-      if( nDirection == DSL_NEAR_END )
-      {
-         memset(&(sAck.ackAtmStatsGet), 0x0, sizeof(sAck.ackAtmStatsGet));
 
-         sCmd.cmdAtmStatsGet.Index  = 0x0;
-         sCmd.cmdAtmStatsGet.Length = 8;
+         /* ATM counters */
+         memset(&(sAck.ackAtmStatsNE_Get), 0x0, sizeof(sAck.ackAtmStatsNE_Get));
 
-         /* Get ATM statistics*/
-         nErrCode = DSL_DRV_VRX_SendMessage(
-            pContext, CMD_ATM_BC0_STATSNE_GET,
-            sizeof(sCmd.cmdAtmStatsGet), (DSL_uint8_t*)&(sCmd.cmdAtmStatsGet),
-            sizeof(sAck.ackAtmStatsGet), (DSL_uint8_t*)&(sAck.ackAtmStatsGet));
+         sCmd.cmdAtmStatsNE_Get.Index  = 0x0;
+         sCmd.cmdAtmStatsNE_Get.Length = 8;
+
+         /* skip fw exchange during training */
+         if (pContext->bGotShowtime)
+         {
+            /* Get ATM statistics*/
+            nErrCode = DSL_DRV_VRX_SendMessage(
+               pContext, CMD_ATM_BC0_STATSNE_GET,
+               sizeof(sCmd.cmdAtmStatsNE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsNE_Get),
+               sizeof(sAck.ackAtmStatsNE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsNE_Get));
+         }
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -796,10 +667,10 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          }
 
          /* Fill the output data structure*/
-         pCounters->nHEC            = (sAck.ackAtmStatsGet.hecp_MSW << 16) | sAck.ackAtmStatsGet.hecp_LSW;
-         pCounters->nTotalCells     = (sAck.ackAtmStatsGet.cdp_MSW << 16) | sAck.ackAtmStatsGet.cdp_LSW;
-         pCounters->nUserTotalCells = (sAck.ackAtmStatsGet.cup_MSW << 16) | sAck.ackAtmStatsGet.cup_LSW;
-         pCounters->nIBE            = (sAck.ackAtmStatsGet.ibep_MSW << 16) | sAck.ackAtmStatsGet.ibep_LSW;
+         pCounters->nHEC            = (sAck.ackAtmStatsNE_Get.hecp_MSW << 16) | sAck.ackAtmStatsNE_Get.hecp_LSW;
+         pCounters->nTotalCells     = (sAck.ackAtmStatsNE_Get.cdp_MSW << 16)  | sAck.ackAtmStatsNE_Get.cdp_LSW;
+         pCounters->nUserTotalCells = (sAck.ackAtmStatsNE_Get.cup_MSW << 16)  | sAck.ackAtmStatsNE_Get.cup_LSW;
+         pCounters->nIBE            = (sAck.ackAtmStatsNE_Get.ibep_MSW << 16) | sAck.ackAtmStatsNE_Get.ibep_LSW;
 
          memset(&(sCmd.cmdAtmTxStatsGet), 0x0, sizeof(sCmd.cmdAtmTxStatsGet));
          memset(&(sAck.ackAtmTxStatsGet), 0x0, sizeof(sAck.ackAtmTxStatsGet));
@@ -807,11 +678,15 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          sCmd.cmdAtmTxStatsGet.Index  = 0;
          sCmd.cmdAtmTxStatsGet.Length = 0x4;
 
-         /* Get ATM Tx statistics*/
-         nErrCode = DSL_DRV_VRX_SendMessage(
-            pContext, CMD_ATM_BC0_TXSTATSNE_GET,
-            sizeof(sCmd.cmdAtmTxStatsGet), (DSL_uint8_t*)&(sCmd.cmdAtmTxStatsGet),
-            sizeof(sAck.ackAtmTxStatsGet), (DSL_uint8_t*)&(sAck.ackAtmTxStatsGet));
+         /* skip fw exchange during training */
+         if (pContext->bGotShowtime)
+         {
+            /* Get ATM Tx statistics*/
+            nErrCode = DSL_DRV_VRX_SendMessage(
+               pContext, CMD_ATM_BC0_TXSTATSNE_GET,
+               sizeof(sCmd.cmdAtmTxStatsGet), (DSL_uint8_t*)&(sCmd.cmdAtmTxStatsGet),
+               sizeof(sAck.ackAtmTxStatsGet), (DSL_uint8_t*)&(sAck.ackAtmTxStatsGet));
+         }
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -831,10 +706,37 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
       }
       else
       {
-         DSL_DEBUG( DSL_DBG_WRN,
-            (pContext, SYS_DBG_WRN"DSL[%02d]: WARNING - Data Path Counters are not supported "
-            "for the ADSL FE!" DSL_DRV_CRLF,
-            DSL_DEV_NUM(pContext)));
+         /* ATM counters */
+         memset(&(sAck.ackAtmStatsFE_Get), 0x0, sizeof(sAck.ackAtmStatsFE_Get));
+
+         sCmd.cmdAtmStatsFE_Get.Index  = 0x0;
+         sCmd.cmdAtmStatsFE_Get.Length = 8;
+
+         /* skip fw exchange during training */
+         if (pContext->bGotShowtime)
+         {
+            /* Get ATM statistics*/
+            nErrCode = DSL_DRV_VRX_SendMessage(
+               pContext, CMD_ATM_BC0_STATSFE_GET,
+               sizeof(sCmd.cmdAtmStatsFE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsFE_Get),
+               sizeof(sAck.ackAtmStatsFE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsFE_Get));
+         }
+
+         /* Check nErrCode and return on error*/
+         if( nErrCode < 0 )
+         {
+            DSL_DEBUG( DSL_DBG_ERR,
+               (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - ATM statistics get failed!"
+               DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+            return nErrCode;
+         }
+
+         /* Fill the output data structure*/
+         pCounters->nHEC            = (sAck.ackAtmStatsFE_Get.hecpfe_MSW << 16) | sAck.ackAtmStatsFE_Get.hecpfe_LSW;
+         pCounters->nTotalCells     = (sAck.ackAtmStatsFE_Get.cdpfe_MSW << 16)  | sAck.ackAtmStatsFE_Get.cdpfe_LSW;
+         pCounters->nUserTotalCells = (sAck.ackAtmStatsFE_Get.cupfe_MSW << 16)  | sAck.ackAtmStatsFE_Get.cupfe_LSW;
+         pCounters->nIBE            = (sAck.ackAtmStatsFE_Get.ibepfe_MSW << 16) | sAck.ackAtmStatsFE_Get.ibepfe_LSW;
       }
    }
    else
@@ -886,13 +788,12 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersSet(
 
    /* Restore counters only if the last showtime FW mode equals to the
       current loaded FW binary*/
-   if( ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2)) &&
-        (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_VDSL)) ||
-       ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL)) &&
-        (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_ADSL)) )
+   if ((DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_VDSL)
+      ||(DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_ADSL))
    {
-      if( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2) )
+      if (nDirection == DSL_NEAR_END)
       {
+         /* PTM counters */
          memset(&(sCmd.PTM), 0x0, sizeof(sCmd.PTM));
          sCmd.PTM.Length = 8;
 
@@ -915,14 +816,13 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersSet(
          if( nErrCode != DSL_SUCCESS )
          {
             DSL_DEBUG( DSL_DBG_ERR,
-               (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - ATM statistics Set failed!"
+               (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - PTM statistics Set failed!"
                DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
             return nErrCode;
          }
-      }
-      else
-      {
+
+         /* ATM counters */
          memset(&(sCmd.ATM), 0x0, sizeof(sCmd.ATM));
          sCmd.ATM.Length = 8;
 
@@ -939,12 +839,10 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersSet(
          sCmd.ATM.ibep_LSW = pCounters->nIBE & 0xFFFF;
          sCmd.ATM.ibep_MSW = (pCounters->nIBE >> 16) & 0xFFFF;
 
-         /* Ignore last 8 parameters (sizeof(sCmd.ATM) - 8 * sizeof(DSL_uint16_t))*/
-
          /* Set ATM statistics*/
          nErrCode = DSL_DRV_VRX_SendMessage(
             pContext, CMD_ATM_BC0_STATSNE_SET,
-            sizeof(sCmd.ATM) - 8 * sizeof(DSL_uint16_t), (DSL_uint8_t*)&(sCmd.ATM),
+            sizeof(sCmd.ATM), (DSL_uint8_t*)&(sCmd.ATM),
             sizeof(sAck.ATM), (DSL_uint8_t*)&(sAck.ATM));
 
          if( nErrCode != DSL_SUCCESS )
@@ -984,11 +882,17 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersSet(
             return nErrCode;
          }
       }
+      else
+      {
+         DSL_DEBUG( DSL_DBG_WRN, (pContext, SYS_DBG_WRN
+            "DSL[%02d]: WARNING - Data Path counters are not supported for the FE!"
+            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+      }
    }
    else
    {
       DSL_DEBUG( DSL_DBG_MSG,
-         (pContext, SYS_DBG_MSG"DSL[%02d]: FW mode switch detected, PM data path counters restore skipped..."
+         (pContext, SYS_DBG_MSG"DSL[%02d]: no PTM/ATM counters need to restore"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
    }
 
@@ -1093,10 +997,11 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersGet(
    memset(&(sAck), 0, sizeof(sAck));
 
    /* For VDSL only mode*/
-   if( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2) )
+   if( DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2) )
    {
       sCmd.NE.Length = 10;
 
+      /* do not skip fw exchange during training because of UAS counter*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_LINEPERFCOUNTNE_GET : CMD_LINEPERFCOUNTFE_GET,
@@ -1115,12 +1020,15 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersGet(
          pCounters->nUAS  = (sAck.NE.cntUAS_MSW << 16) | sAck.NE.cntUAS_LSW;
          /* Not supported by the VRX VDSL FW*/
          pCounters->nLOFS = 0;
+         /* Get current FECS value*/
+         pCounters->nFECS  = (sAck.NE.cntFECS_MSW << 16) | sAck.NE.cntFECS_LSW;
       }
    }
-   else if(DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL))
+   else if(DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL))
    {
       sCmd.NE.Length = 10;
 
+      /* do not skip fw exchange during training because of UAS counter*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_LINEPERFCOUNTNE_GET : CMD_LINEPERFCOUNTFE_GET,
@@ -1139,6 +1047,8 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersGet(
          pCounters->nUAS  = 0;
          /* LOFS counter not supported by the FW in the ADSL mode*/
          pCounters->nLOFS = 0;
+         /* Get current FECS value*/
+         pCounters->nFECS  = (sAck.NE.cntFECS_MSW << 16) | sAck.NE.cntFECS_LSW;
       }
    }
    else
@@ -1181,7 +1091,7 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersSet(
 
    DSL_DEBUG( DSL_DBG_MSG,
       (pContext,SYS_DBG_MSG"DSL[%02d]: IN - DSL_DRV_PM_DEV_LineSecCountersSet,"
-      " (nDirection=%s)"DSL_DRV_CRLF, DSL_DEV_NUM(pContext), 
+      " (nDirection=%s)"DSL_DRV_CRLF, DSL_DEV_NUM(pContext),
        nDirection==DSL_NEAR_END ? "NE":"FE"));
 
    if (nDirection == DSL_FAR_END)
@@ -1195,54 +1105,31 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersSet(
 
    /* Restore counters only if the last showtime FW mode equals to the
       current loaded FW binary*/
-   if( ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2)) &&
+   if( ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_VDSL)) ||
-       ((DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_ADSL)) &&
+       ((DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL)) &&
         (DSL_DRV_PM_CONTEXT(pContext)->nLastShowtime == DSL_PM_FWMODE_ADSL)) )
    {
-      /* Only applicable for ADSL mode*/
-      if( DSL_DRV_VXX_FwFeatureCheck(pContext, DSL_VXX_FW_VDSL2) )
-      {
-         memset(&(sCmd.LinePerfNE), 0x0, sizeof(sCmd.LinePerfNE));
+      memset(&(sCmd.LinePerfNE), 0x0, sizeof(sCmd.LinePerfNE));
 
-         /* Fill the message*/
-         sCmd.LinePerfNE.Length      = 10;
-         sCmd.LinePerfNE.cntES_MSW   = (DSL_uint16_t)(pCounters->nES>>16);
-         sCmd.LinePerfNE.cntES_LSW   = (DSL_uint16_t)pCounters->nES;
-         sCmd.LinePerfNE.cntSES_MSW  = (DSL_uint16_t)(pCounters->nSES>>16);
-         sCmd.LinePerfNE.cntSES_LSW  = (DSL_uint16_t)(pCounters->nSES);
-         sCmd.LinePerfNE.cntES_MSW   = (DSL_uint16_t)(pCounters->nLOSS>>16);
-         sCmd.LinePerfNE.cntLOSS_LSW = (DSL_uint16_t)(pCounters->nLOSS);
-         sCmd.LinePerfNE.cntUAS_MSW  = (DSL_uint16_t)(pCounters->nUAS>>16);
-         sCmd.LinePerfNE.cntUAS_LSW  = (DSL_uint16_t)(pCounters->nUAS);
+      /* Fill the message*/
+      sCmd.LinePerfNE.Length      = 10;
+      sCmd.LinePerfNE.cntFECS_MSW = (DSL_uint16_t)(pCounters->nFECS>>16);
+      sCmd.LinePerfNE.cntFECS_LSW = (DSL_uint16_t)pCounters->nFECS;
+      sCmd.LinePerfNE.cntES_MSW   = (DSL_uint16_t)(pCounters->nES>>16);
+      sCmd.LinePerfNE.cntES_LSW   = (DSL_uint16_t)pCounters->nES;
+      sCmd.LinePerfNE.cntSES_MSW  = (DSL_uint16_t)(pCounters->nSES>>16);
+      sCmd.LinePerfNE.cntSES_LSW  = (DSL_uint16_t)(pCounters->nSES);
+      sCmd.LinePerfNE.cntLOSS_MSW = (DSL_uint16_t)(pCounters->nLOSS>>16);
+      sCmd.LinePerfNE.cntLOSS_LSW = (DSL_uint16_t)(pCounters->nLOSS);
+      sCmd.LinePerfNE.cntUAS_MSW  = (DSL_uint16_t)(pCounters->nUAS>>16);
+      sCmd.LinePerfNE.cntUAS_LSW  = (DSL_uint16_t)(pCounters->nUAS);
 
-         /* Set Line sec counters*/
-         nErrCode =  DSL_DRV_VRX_SendMessage(
-            pContext, CMD_LINEPERFCOUNTNE_SET,
-            sizeof(sCmd.LinePerfNE), (DSL_uint8_t *)&(sCmd.LinePerfNE),
-            sizeof(sAck.LinePerfNE),(DSL_uint8_t *)&(sAck.LinePerfNE));
-      }
-      else
-      {
-         memset(&(sCmd.LinePerfNE), 0x0, sizeof(sCmd.LinePerfNE));
-
-         /* Fill the message*/
-         sCmd.LinePerfNE.Length      = 10;
-         sCmd.LinePerfNE.cntES_MSW   = (DSL_uint16_t)(pCounters->nES>>16);
-         sCmd.LinePerfNE.cntES_LSW   = (DSL_uint16_t)pCounters->nES;
-         sCmd.LinePerfNE.cntSES_MSW  = (DSL_uint16_t)(pCounters->nSES>>16);
-         sCmd.LinePerfNE.cntSES_LSW  = (DSL_uint16_t)(pCounters->nSES);
-         sCmd.LinePerfNE.cntLOSS_MSW = (DSL_uint16_t)(pCounters->nLOSS>>16);
-         sCmd.LinePerfNE.cntLOSS_LSW = (DSL_uint16_t)(pCounters->nLOSS);
-         sCmd.LinePerfNE.cntUAS_MSW  = (DSL_uint16_t)(pCounters->nUAS>>16);
-         sCmd.LinePerfNE.cntUAS_LSW  = (DSL_uint16_t)(pCounters->nUAS);
-
-         /* Set Line sec counters*/
-         nErrCode =  DSL_DRV_VRX_SendMessage(
-            pContext, CMD_LINEPERFCOUNTNE_SET,
-            sizeof(sCmd.LinePerfNE), (DSL_uint8_t *)&(sCmd.LinePerfNE),
-            sizeof(sAck.LinePerfNE),(DSL_uint8_t *)&(sAck.LinePerfNE));
-      }
+      /* Set Line sec counters*/
+      nErrCode =  DSL_DRV_VRX_SendMessage(
+         pContext, CMD_LINEPERFCOUNTNE_SET,
+         sizeof(sCmd.LinePerfNE), (DSL_uint8_t *)&(sCmd.LinePerfNE),
+         sizeof(sAck.LinePerfNE),(DSL_uint8_t *)&(sAck.LinePerfNE));
    }
    else
    {
@@ -1482,6 +1369,14 @@ DSL_Error_t DSL_DRV_PM_DEV_ReTxCountersGet(
    DSL_PM_ReTxData_t *pCounters)
 {
    DSL_Error_t nErrCode = DSL_SUCCESS;
+   union
+   {
+      ACK_RTX_PM_US_Get_t US;
+      ACK_RTX_PM_DS_Get_t DS;
+   } retxPm;
+
+   DSL_uint32_t nEftrMin = 0;
+   DSL_DEV_VersionCheck_t nVerCheck = DSL_VERSION_ERROR;
 
    DSL_DEBUG( DSL_DBG_MSG,
       (pContext, SYS_DBG_MSG"DSL[%02d]: IN - DSL_DRV_PM_DEV_ReTxCountersGet"
@@ -1491,7 +1386,87 @@ DSL_Error_t DSL_DRV_PM_DEV_ReTxCountersGet(
    DSL_CHECK_ATU_DIRECTION(nDirection);
    DSL_CHECK_ERR_CODE();
 
-   memset(pCounters, 0x0, sizeof(DSL_PM_ReTxData_t));
+   memset(&retxPm, 0x0, sizeof(retxPm));
+
+   if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2))
+   {
+      /* Get FW information */
+      nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                  DSL_MIN_FW_VERSION_RETX_VDSL_DS, &nVerCheck);
+      if (nErrCode != DSL_SUCCESS)
+      {
+         DSL_DEBUG(DSL_DBG_ERR,
+            (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+         return nErrCode;
+      }
+   }
+   else if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_ADSL))
+   {
+      /* Important: API direction mapping to the FW (NE->DS, FE->US) */
+      /* US for ADSL is not supported */
+      if (nDirection == DSL_NEAR_END)
+      {
+         /* Get FW information */
+         nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                     DSL_MIN_FW_VERSION_RETX_ADSL_DS, &nVerCheck);
+         if (nErrCode != DSL_SUCCESS)
+         {
+            DSL_DEBUG(DSL_DBG_ERR,
+               (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+               DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+            return nErrCode;
+         }
+      }
+   }
+
+   if (nVerCheck >= DSL_VERSION_EQUAL)
+   {
+      /* Important: API direction mapping to the FW (NE->DS, FE->US) */
+      nErrCode = DSL_DRV_VRX_SendMsgRtxPmGet(
+                                  pContext,
+                                  nDirection == DSL_NEAR_END ? DSL_DOWNSTREAM :
+                                                               DSL_UPSTREAM,
+                                  (DSL_uint8_t *)&retxPm);
+      if (nErrCode != DSL_SUCCESS)
+      {
+         DSL_DEBUG(DSL_DBG_ERR, (pContext,
+            SYS_DBG_ERR"DSL[%02d]: ERROR - ReTx PM counters read failed!"
+            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+         return nErrCode;
+      }
+
+      if (nDirection == DSL_NEAR_END)
+      {
+         pCounters->nErrorFreeBits = ((DSL_uint32_t)(retxPm.US.ErrorFreeBits_MSW << 16)) |
+                                                     retxPm.US.ErrorFreeBits_LSW;
+         pCounters->nLeftr         = ((DSL_uint32_t)(retxPm.US.leftr_MSW << 16)) |
+                                                     retxPm.US.leftr_LSW;
+         nEftrMin                  = ((DSL_uint32_t)(retxPm.US.EFTR_min_MSW << 16)) |
+                                                     retxPm.US.EFTR_min_LSW;
+      }
+      else
+      {
+         pCounters->nErrorFreeBits = ((DSL_uint32_t)(retxPm.DS.ErrorFreeBits_MSW << 16)) |
+                                                     retxPm.DS.ErrorFreeBits_LSW;
+         pCounters->nLeftr         = ((DSL_uint32_t)(retxPm.DS.leftr_MSW << 16)) |
+                                                     retxPm.DS.leftr_LSW;
+         nEftrMin                  = ((DSL_uint32_t)(retxPm.DS.EFTR_MSW << 16)) |
+                                                     retxPm.DS.EFTR_LSW;
+      }
+
+      /* ignore zero value*/
+      if (nEftrMin)
+      {
+         /* Fw Format:  kBit/s */
+         /* API format: bit/s */
+         pCounters->nEftrMin = nEftrMin*1000;
+      }
+   }
+   else
+   {
+      memset(pCounters, 0x0, sizeof(DSL_PM_ReTxData_t));
+   }
 
    DSL_DEBUG( DSL_DBG_MSG,
       (pContext, SYS_DBG_MSG"DSL[%02d]: OUT - DSL_DRV_PM_DEV_ReTxCountersGet (retCode=%d)"
